@@ -1,4 +1,4 @@
-//  Copyright (C) 2001  MandrakeSoft S.A.
+//  Copyright (C) 2000  MandrakeSoft S.A.
 //
 //    MandrakeSoft S.A.
 //    43, rue d'Aboukir
@@ -85,15 +85,6 @@
 #define BX_32BIT_REG_EDI 7
 
 
-#if defined(NEED_CPU_REG_SHORTCUTS)
-
-/* WARNING: 
-   Only BX_CPU_C member functions can use these shortcuts safely!
-   Functions that use the shortcuts outside of BX_CPU_C might work 
-   when BX_USE_CPU_SMF=1 but will fail when BX_USE_CPU_SMF=0
-   (for example in SMP mode).
-*/
-
 // access to 8 bit general registers
 #define AL (BX_CPU_THIS_PTR gen_reg[0].word.byte.rl)
 #define CL (BX_CPU_THIS_PTR gen_reg[1].word.byte.rl)
@@ -132,7 +123,6 @@
 // access to 32 bit instruction pointer
 #define EIP BX_CPU_THIS_PTR eip
 
-
 #define BX_READ_8BIT_REG(index)  (((index) < 4) ? \
   (BX_CPU_THIS_PTR gen_reg[index].word.byte.rl) : \
   (BX_CPU_THIS_PTR gen_reg[(index)-4].word.byte.rh))
@@ -172,9 +162,6 @@
 #define CPL  (BX_CPU_THIS_PTR sregs[BX_SEG_REG_CS].selector.rpl)
 #endif
 
-
-#endif  // defined(NEED_CPU_REG_SHORTCUTS)
-
 #define BX_DE_EXCEPTION   0 // Divide Error (fault)
 #define BX_DB_EXCEPTION   1 // Debug (fault/trap)
 #define BX_BP_EXCEPTION   3 // Breakpoint (trap)
@@ -381,7 +368,6 @@ typedef struct {
   } bx_segment_reg_t;
 
 typedef void * (*BxVoidFPtr_t)(void);
-class BX_CPU_C;
 
 typedef struct BxInstruction_tag {
   // prefix stuff here...
@@ -409,18 +395,11 @@ typedef struct BxInstruction_tag {
   unsigned ilen; // instruction length
   unsigned os_32, as_32; // OperandSize/AddressSize is 32bit
   unsigned flags_in, flags_out; // flags needed, flags modified
-
-#if BX_USE_CPU_SMF
   void (*ResolveModrm)(BxInstruction_tag *);
-  void (*execute)(BxInstruction_tag *);
-#else
-  void (BX_CPU_C::*ResolveModrm)(BxInstruction_tag *);
-  void (BX_CPU_C::*execute)(BxInstruction_tag *);
-#endif
-
 #if BX_DYNAMIC_TRANSLATION
   BxVoidFPtr_t DTResolveModrm;
 #endif
+  void (*execute)(BxInstruction_tag *);
 #if BX_DYNAMIC_TRANSLATION
   unsigned DTAttr;
   Bit8u *   (*DTFPtr)(Bit8u *, BxInstruction_tag *);
@@ -428,13 +407,7 @@ typedef struct BxInstruction_tag {
 #endif
   } BxInstruction_t;
 
-#if BX_USE_CPU_SMF
 typedef void (*BxExecutePtr_t)(BxInstruction_t *);
-#else
-typedef void (BX_CPU_C::*BxExecutePtr_t)(BxInstruction_t *);
-#endif
-
-
 #if BX_DYNAMIC_TRANSLATION
 typedef Bit8u * (*BxDTASResolveModrm_t)(Bit8u *, BxInstruction_t *,
   unsigned, unsigned);
@@ -511,145 +484,25 @@ typedef struct {
 #endif
 
 
-typedef enum {
-  APIC_TYPE_NONE,
-  APIC_TYPE_IOAPIC,
-  APIC_TYPE_LOCAL_APIC
-} bx_apic_type_t;
 
-#if BX_SUPPORT_APIC
-class bx_generic_apic_c : public logfunctions {
-protected:
-  Bit32u base_addr;
-  Bit8u id;
-#define APIC_UNKNOWN_ID 0xff
-#define APIC_VERSION_ID 0x00170011  // same version as 82093 IOAPIC
-public:
-  bx_generic_apic_c ();
-  virtual ~bx_generic_apic_c ();
-  virtual void init ();
-  virtual void hwreset () { }
-  Bit32u get_base (void) { return base_addr; }
-  void set_base (Bit32u newbase);
-  void set_id (Bit8u newid);
-  Bit8u get_id () { return id; }
-  virtual char *get_name();
-  Boolean is_selected (Bit32u addr, Bit32u len);
-  void read (Bit32u addr, void *data, unsigned len);
-  virtual void read_aligned(Bit32u address, Bit32u *data, unsigned len);
-  virtual void write(Bit32u address, Bit32u *value, unsigned len);
-  virtual void startup_msg (Bit32u vector);
-  // on local APIC, trigger means deliver to the CPU.
-  // on I/O APIC, trigger means direct to another APIC according to table.
-  virtual void trigger_irq (unsigned num, unsigned from);
-  virtual void untrigger_irq (unsigned num, unsigned from);
-  virtual Bit32u get_delivery_bitmask (Bit8u dest, Bit8u dest_mode);
-  Boolean deliver (Bit8u destination, Bit8u dest_mode, Bit8u delivery_mode, Bit8u vector, Bit8u polarity, Bit8u trig_mode);
-  virtual Boolean match_logical_addr (Bit8u address);
-  virtual bx_apic_type_t get_type ();
-};
-
-class bx_local_apic_c : public bx_generic_apic_c {
-#define BX_LOCAL_APIC_MAX_INTS 256
-  // TMR=trigger mode register.  Cleared for edge-triggered interrupts
-  // and set for level-triggered interrupts.  If set, local APIC must send
-  // EOI message to all other APICs.  EOI's are not implemented.
-  Bit8u tmr[BX_LOCAL_APIC_MAX_INTS];
-  // IRR=interrupt request register.  When an interrupt is triggered by
-  // the I/O APIC or another processor, it sets a bit in irr.  The bit is
-  // cleared when the interrupt is acknowledged by the processor.
-  Bit8u irr[BX_LOCAL_APIC_MAX_INTS];
-  // ISR=in-service register.  When an IRR bit is cleared, the corresponding
-  // bit in ISR is set.  The ISR bit is cleared when 
-  Bit8u isr[BX_LOCAL_APIC_MAX_INTS];
-  Bit32u arb_id, arb_priority, task_priority, log_dest, dest_format, spurious_vec;
-  Bit32u lvt[6];
-#define APIC_LVT_TIMER   0
-#define APIC_LVT_THERMAL 1
-#define APIC_LVT_PERFORM 2
-#define APIC_LVT_LINT0   3
-#define APIC_LVT_LINT1   4
-#define APIC_LVT_ERROR   5
-  Bit32u timer_initial, timer_current, timer_divconf;
-  Boolean timer_active;  // internal state, not accessible from bus
-  Bit32u timer_divide_counter, timer_divide_factor;
-  Bit32u apic_base_msr;
-  Bit32u icr_high, icr_low;
-  Bit32u err_status;
-#define APIC_ERR_ILLEGAL_ADDR    0x80
-#define APIC_ERR_RX_ILLEGAL_VEC  0x40
-#define APIC_ERR_TX_ILLEGAL_VEC  0x20
-#define APIC_ERR_RX_ACCEPT_ERR   0x08
-#define APIC_ERR_TX_ACCEPT_ERR   0x04
-#define APIC_ERR_RX_CHECKSUM     0x02
-#define APIC_ERR_TX_CHECKSUM     0x01
-public:
-  bx_local_apic_c(BX_CPU_C *mycpu);
-  virtual ~bx_local_apic_c(void);
-  BX_CPU_C *cpu;
-  virtual void hwreset ();
-  virtual void init ();
-  BX_CPU_C *get_cpu (Bit8u id);
-  void set_id (Bit8u newid);   // redefine to set cpu->name
-  virtual char *get_name();
-  virtual void write (Bit32u addr, Bit32u *data, unsigned len);
-  virtual void read_aligned(Bit32u address, Bit32u *data, unsigned len);
-  virtual void startup_msg (Bit32u vector);
-  // on local APIC, trigger means raise the CPU's INTR line.  For now
-  // I also have to raise pc_system.INTR but that should be replaced
-  // with the cpu-specific INTR signals.
-  virtual void trigger_irq (unsigned num, unsigned from);
-  virtual void untrigger_irq (unsigned num, unsigned from);
-  Bit8u acknowledge_int ();  // only the local CPU should call this
-  int highest_priority_int (Bit8u *array);
-  void service_local_apic ();
-  void print_status ();
-  virtual Boolean match_logical_addr (Bit8u address);
-  virtual Boolean is_local_apic () { return true; }
-  virtual bx_apic_type_t get_type () { return APIC_TYPE_LOCAL_APIC; }
-  virtual Bit32u get_delivery_bitmask (Bit8u dest, Bit8u dest_mode);
-  Bit8u get_ppr ();
-  Bit8u get_apr ();
-  void periodic (Bit32u usec_delta);
-  void set_divide_configuration (Bit32u value);
-  };
-
-#define APIC_MAX_ID 16
-extern bx_generic_apic_c *apic_index[APIC_MAX_ID];
-#endif // if BX_SUPPORT_APIC
-
-
-#if BX_USE_CPU_SMF == 0
-// normal member functions.  This can ONLY be used within BX_CPU_C classes.
-// Anyone on the outside should use the BX_CPU macro (defined in bochs.h) 
-// instead.
+#if BX_USE_SMF == 0
+   // normal member functions, use this pointer
 #  define BX_CPU_THIS_PTR  this->
 #  define BX_SMF
 #  define BX_CPU_C_PREFIX  BX_CPU_C::
-// with normal member functions, calling a member fn pointer looks like
-// object->*(fnptr)(arg, ...);
-// Since this is different from when SMF=1, encapsulate it in a macro.
-#  define BX_CPU_CALL_METHOD(func, args) \
-    (this->*((BxExecutePtr_t) (func))) args
 #else
-// static member functions.  With SMF, there is only one CPU by definition.
-#  define BX_CPU_THIS_PTR  BX_CPU(0)->
+   // static member functions, use direct access
+#  define BX_CPU_THIS_PTR  BX_CPU.
 #  define BX_SMF           static
 #  define BX_CPU_C_PREFIX
-#  define BX_CPU_CALL_METHOD(func, args) \
-    ((BxExecutePtr_t) (func)) args
 #endif
 
 typedef void (*BxDTShim_t)(void);
 
-class BX_MEM_C;
-
-class BX_CPU_C : public logfunctions {
+class BX_CPU_C {
 
 public: // for now...
 
-  char name[64];
-
   // General register set
   // eax: accumulator
   // ebx: base
@@ -741,9 +594,6 @@ public: // for now...
   Bit32u    cr4;
 #endif
 
-  // pointer to the address space that this processor uses.
-  BX_MEM_C *mem;
-
   Boolean EXT; /* 1 if processing external interrupt or exception
                 * or if not related to current instruction,
                 * 0 if current CS:IP caused exception */
@@ -751,7 +601,7 @@ public: // for now...
 
   Bit32u   debug_trap; // holds DR6 value to be set as well
   volatile Boolean async_event;
-  volatile Boolean INTR;
+
 
   // for accessing registers by index number
   Bit16u *_16bit_base_reg[8];
@@ -796,7 +646,6 @@ public: // for now...
   Boolean debug_vm;		/* BW contains current mode*/
   Bit8u show_eip;		/* BW record eip at special instr f.ex eip */
   Bit8u show_flag;		/* BW shows instr class executed */
-  bx_guard_found_t guard_found;
 #endif
 
   // for paging
@@ -823,9 +672,8 @@ public: // for now...
   BX_SMF Boolean get_CF(void);
 
   // constructors & destructors...
-  BX_CPU_C();
+  BX_CPU_C(void);
   ~BX_CPU_C(void);
-  void init (BX_MEM_C *addrspace);
 
   // prototypes for CPU instructions...
   BX_SMF void ADD_EbGb(BxInstruction_t *);
@@ -1281,8 +1129,6 @@ public: // for now...
   BX_SMF void dynamic_init(void);
   BX_SMF unsigned FetchDecode(Bit8u *, BxInstruction_t *, unsigned, Boolean);
   BX_SMF void UndefinedOpcode(BxInstruction_t *);
-  BX_SMF void BxError(BxInstruction_t *i);
-  BX_SMF void BxResolveError(BxInstruction_t *i);
 
   BX_SMF void Resolve16Mod0Rm0(BxInstruction_t *);
   BX_SMF void Resolve16Mod0Rm1(BxInstruction_t *);
@@ -1361,7 +1207,7 @@ public: // for now...
   BX_SMF void     atexit(void);
 
   // now for some ancillary functions...
-  BX_SMF void cpu_loop(Bit32s max_instr_count);
+  BX_SMF void cpu_loop(void);
   BX_SMF void decode_exgx16(unsigned need_fetch);
   BX_SMF void decode_exgx32(unsigned need_fetch);
 
@@ -1462,52 +1308,48 @@ public: // for now...
                                  unsigned opa, unsigned opb);
 #endif
 
-  BX_SMF BX_CPP_INLINE void set_CF(Boolean val);
-  BX_SMF BX_CPP_INLINE void set_AF(Boolean val);
-  BX_SMF BX_CPP_INLINE void set_ZF(Boolean val);
-  BX_SMF BX_CPP_INLINE void set_SF(Boolean val);
-  BX_SMF BX_CPP_INLINE void set_OF(Boolean val);
-  BX_SMF BX_CPP_INLINE void set_PF(Boolean val);
-  BX_SMF BX_CPP_INLINE void set_PF_base(Bit8u val);
+  BX_SMF inline void set_CF(Boolean val);
+  BX_SMF inline void set_AF(Boolean val);
+  BX_SMF inline void set_ZF(Boolean val);
+  BX_SMF inline void set_SF(Boolean val);
+  BX_SMF inline void set_OF(Boolean val);
+  BX_SMF inline void set_PF(Boolean val);
+  BX_SMF inline void set_PF_base(Bit8u val);
 
 
-  BX_SMF BX_CPP_INLINE void set_AX(Bit16u ax);
-  BX_SMF BX_CPP_INLINE void set_BX(Bit16u bx);
-  BX_SMF BX_CPP_INLINE void set_CX(Bit16u cx);
-  BX_SMF BX_CPP_INLINE void set_DX(Bit16u dx);
-  BX_SMF BX_CPP_INLINE void set_AL(Bit8u  al);
-  BX_SMF BX_CPP_INLINE void set_AH(Bit8u  ah);
-  BX_SMF BX_CPP_INLINE void set_BL(Bit8u  bl);
-  BX_SMF BX_CPP_INLINE void set_BH(Bit8u  bh);
-  BX_SMF BX_CPP_INLINE void set_CL(Bit8u  cl);
-  BX_SMF BX_CPP_INLINE void set_CH(Bit8u  ch);
-  BX_SMF BX_CPP_INLINE void set_DL(Bit8u  dl);
-  BX_SMF BX_CPP_INLINE void set_DH(Bit8u  dh);
+  BX_SMF inline void set_AX(Bit16u ax);
+  BX_SMF inline void set_BX(Bit16u bx);
+  BX_SMF inline void set_CX(Bit16u cx);
+  BX_SMF inline void set_DX(Bit16u dx);
+  BX_SMF inline void set_AL(Bit8u  al);
+  BX_SMF inline void set_AH(Bit8u  ah);
+  BX_SMF inline void set_BL(Bit8u  bl);
+  BX_SMF inline void set_BH(Bit8u  bh);
+  BX_SMF inline void set_CL(Bit8u  cl);
+  BX_SMF inline void set_CH(Bit8u  ch);
+  BX_SMF inline void set_DL(Bit8u  dl);
+  BX_SMF inline void set_DH(Bit8u  dh);
 
-  BX_SMF BX_CPP_INLINE Bit8u get_AL(void);
-  BX_SMF BX_CPP_INLINE Bit8u get_AH(void);
-  BX_SMF BX_CPP_INLINE Bit8u get_BL(void);
-  BX_SMF BX_CPP_INLINE Bit8u get_BH(void);
-  BX_SMF BX_CPP_INLINE Bit8u get_CL(void);
-  BX_SMF BX_CPP_INLINE Bit8u get_CH(void);
-  BX_SMF BX_CPP_INLINE Bit8u get_DL(void);
-  BX_SMF BX_CPP_INLINE Bit8u get_DH(void);
+  BX_SMF inline Bit8u get_AL(void);
+  BX_SMF inline Bit8u get_AH(void);
+  BX_SMF inline Bit8u get_BL(void);
+  BX_SMF inline Bit8u get_BH(void);
+  BX_SMF inline Bit8u get_CL(void);
+  BX_SMF inline Bit8u get_CH(void);
+  BX_SMF inline Bit8u get_DL(void);
+  BX_SMF inline Bit8u get_DH(void);
 
-  BX_SMF BX_CPP_INLINE Bit16u get_AX(void);
-  BX_SMF BX_CPP_INLINE Bit16u get_BX(void);
-  BX_SMF BX_CPP_INLINE Bit16u get_CX(void);
-  BX_SMF BX_CPP_INLINE Bit16u get_DX(void);
+  BX_SMF inline Bit16u get_AX(void);
+  BX_SMF inline Bit16u get_BX(void);
+  BX_SMF inline Bit16u get_CX(void);
+  BX_SMF inline Bit16u get_DX(void);
 
 #if BX_CPU_LEVEL >= 2
-  BX_SMF BX_CPP_INLINE Boolean real_mode(void);
+  BX_SMF inline Boolean real_mode(void);
 #endif
 #if BX_CPU_LEVEL >= 3
-  BX_SMF BX_CPP_INLINE Boolean protected_mode(void);
-  BX_SMF BX_CPP_INLINE Boolean v8086_mode(void);
-#endif
-#if BX_SUPPORT_APIC
-  bx_local_apic_c local_apic;
-  Boolean int_from_local_apic;
+  BX_SMF inline Boolean protected_mode(void);
+  BX_SMF inline Boolean v8086_mode(void);
 #endif
   };
 
@@ -1520,117 +1362,108 @@ public: // for now...
 #endif
 
 
-#if BX_SMP_PROCESSORS==1
-// single processor simulation, so there's one of everything
-extern BX_CPU_C       bx_cpu;
-#else
-// multiprocessor simulation, we need an array of cpus and memories
-extern BX_CPU_C       *bx_cpu_array[BX_SMP_PROCESSORS];
-#endif
+extern BX_CPU_C       BX_CPU;
 
-#if defined(NEED_CPU_REG_SHORTCUTS)
 
-BX_SMF BX_CPP_INLINE void BX_CPU_C_PREFIX set_AX(Bit16u ax) { AX = ax; };
-BX_SMF BX_CPP_INLINE void BX_CPU_C_PREFIX set_BX(Bit16u bx) { BX = bx; };
-BX_SMF BX_CPP_INLINE void BX_CPU_C_PREFIX set_CX(Bit16u cx) { CX = cx; };
-BX_SMF BX_CPP_INLINE void BX_CPU_C_PREFIX set_DX(Bit16u dx) { DX = dx; };
-BX_SMF BX_CPP_INLINE void BX_CPU_C_PREFIX set_AL(Bit8u  al) { AL = al; };
-BX_SMF BX_CPP_INLINE void BX_CPU_C_PREFIX set_AH(Bit8u  ah) { AH = ah; };
-BX_SMF BX_CPP_INLINE void BX_CPU_C_PREFIX set_BL(Bit8u  bl) { BL = bl; };
-BX_SMF BX_CPP_INLINE void BX_CPU_C_PREFIX set_BH(Bit8u  bh) { BH = bh; };
-BX_SMF BX_CPP_INLINE void BX_CPU_C_PREFIX set_CL(Bit8u  cl) { CL = cl; };
-BX_SMF BX_CPP_INLINE void BX_CPU_C_PREFIX set_CH(Bit8u  ch) { CH = ch; };
-BX_SMF BX_CPP_INLINE void BX_CPU_C_PREFIX set_DL(Bit8u  dl) { DL = dl; };
-BX_SMF BX_CPP_INLINE void BX_CPU_C_PREFIX set_DH(Bit8u  dh) { DH = dh; };
+BX_SMF inline void BX_CPU_C_PREFIX set_AX(Bit16u ax) { AX = ax; };
+BX_SMF inline void BX_CPU_C_PREFIX set_BX(Bit16u bx) { BX = bx; };
+BX_SMF inline void BX_CPU_C_PREFIX set_CX(Bit16u cx) { CX = cx; };
+BX_SMF inline void BX_CPU_C_PREFIX set_DX(Bit16u dx) { DX = dx; };
+BX_SMF inline void BX_CPU_C_PREFIX set_AL(Bit8u  al) { AL = al; };
+BX_SMF inline void BX_CPU_C_PREFIX set_AH(Bit8u  ah) { AH = ah; };
+BX_SMF inline void BX_CPU_C_PREFIX set_BL(Bit8u  bl) { BL = bl; };
+BX_SMF inline void BX_CPU_C_PREFIX set_BH(Bit8u  bh) { BH = bh; };
+BX_SMF inline void BX_CPU_C_PREFIX set_CL(Bit8u  cl) { CL = cl; };
+BX_SMF inline void BX_CPU_C_PREFIX set_CH(Bit8u  ch) { CH = ch; };
+BX_SMF inline void BX_CPU_C_PREFIX set_DL(Bit8u  dl) { DL = dl; };
+BX_SMF inline void BX_CPU_C_PREFIX set_DH(Bit8u  dh) { DH = dh; };
 
-BX_SMF BX_CPP_INLINE Bit8u BX_CPU_C_PREFIX get_AL(void) { return(AL); };
-BX_SMF BX_CPP_INLINE Bit8u BX_CPU_C_PREFIX get_AH(void) { return(AH); };
-BX_SMF BX_CPP_INLINE Bit8u BX_CPU_C_PREFIX get_BL(void) { return(BL); };
-BX_SMF BX_CPP_INLINE Bit8u BX_CPU_C_PREFIX get_BH(void) { return(BH); };
-BX_SMF BX_CPP_INLINE Bit8u BX_CPU_C_PREFIX get_CL(void) { return(CL); };
-BX_SMF BX_CPP_INLINE Bit8u BX_CPU_C_PREFIX get_CH(void) { return(CH); };
-BX_SMF BX_CPP_INLINE Bit8u BX_CPU_C_PREFIX get_DL(void) { return(DL); };
-BX_SMF BX_CPP_INLINE Bit8u BX_CPU_C_PREFIX get_DH(void) { return(DH); };
+BX_SMF inline Bit8u BX_CPU_C_PREFIX get_AL(void) { return(AL); };
+BX_SMF inline Bit8u BX_CPU_C_PREFIX get_AH(void) { return(AH); };
+BX_SMF inline Bit8u BX_CPU_C_PREFIX get_BL(void) { return(BL); };
+BX_SMF inline Bit8u BX_CPU_C_PREFIX get_BH(void) { return(BH); };
+BX_SMF inline Bit8u BX_CPU_C_PREFIX get_CL(void) { return(CL); };
+BX_SMF inline Bit8u BX_CPU_C_PREFIX get_CH(void) { return(CH); };
+BX_SMF inline Bit8u BX_CPU_C_PREFIX get_DL(void) { return(DL); };
+BX_SMF inline Bit8u BX_CPU_C_PREFIX get_DH(void) { return(DH); };
 
-BX_SMF BX_CPP_INLINE Bit16u BX_CPU_C_PREFIX get_AX(void) { return(AX); };
-BX_SMF BX_CPP_INLINE Bit16u BX_CPU_C_PREFIX get_BX(void) { return(BX); };
-BX_SMF BX_CPP_INLINE Bit16u BX_CPU_C_PREFIX get_CX(void) { return(CX); };
-BX_SMF BX_CPP_INLINE Bit16u BX_CPU_C_PREFIX get_DX(void) { return(DX); };
-
-#endif
+BX_SMF inline Bit16u BX_CPU_C_PREFIX get_AX(void) { return(AX); };
+BX_SMF inline Bit16u BX_CPU_C_PREFIX get_BX(void) { return(BX); };
+BX_SMF inline Bit16u BX_CPU_C_PREFIX get_CX(void) { return(CX); };
+BX_SMF inline Bit16u BX_CPU_C_PREFIX get_DX(void) { return(DX); };
 
 
 #if BX_CPU_LEVEL >= 2
-  BX_CPP_INLINE Boolean BX_CPU_C::real_mode(void) { return( !BX_CPU_THIS_PTR cr0.pe ); };
+  inline Boolean BX_CPU_C::real_mode(void) { return( !BX_CPU_THIS_PTR cr0.pe ); };
 #endif
 
 #if BX_CPU_LEVEL == 2
-  BX_CPP_INLINE Boolean BX_CPU_C::protected_mode(void) { return( BX_CPU_THIS_PTR cr0.pe ); };
+  inline Boolean BX_CPU_C::protected_mode(void) { return( BX_CPU_THIS_PTR cr0.pe ); };
 #endif
 
 
 #if BX_CPU_LEVEL >= 3
 #  if BX_SUPPORT_V8086_MODE
-  BX_CPP_INLINE Boolean
+  inline Boolean
 BX_CPU_C::v8086_mode(void) {
   return(BX_CPU_THIS_PTR eflags.vm);
   }
 
-  BX_CPP_INLINE Boolean
+  inline Boolean
 BX_CPU_C::protected_mode(void) {
   return(BX_CPU_THIS_PTR cr0.pe && !BX_CPU_THIS_PTR eflags.vm);
   }
 #  else
-  BX_CPP_INLINE Boolean
+  inline Boolean
 BX_CPU_C::v8086_mode(void) {
   return(0);
   }
 
-  BX_CPP_INLINE Boolean
+  inline Boolean
 BX_CPU_C::protected_mode(void) {
   return(BX_CPU_THIS_PTR cr0.pe);
   }
 #  endif
 #endif
 
-    BX_CPP_INLINE void
+    inline void
 BX_CPU_C::set_CF(Boolean val) {
     BX_CPU_THIS_PTR lf_flags_status &= 0xfffff0;
     BX_CPU_THIS_PTR eflags.cf = val;
     }
 
-    BX_CPP_INLINE void
+    inline void
 BX_CPU_C::set_AF(Boolean val) {
     BX_CPU_THIS_PTR lf_flags_status &= 0xfff0ff;
     BX_CPU_THIS_PTR eflags.af = val;
     }
 
-    BX_CPP_INLINE void
+    inline void
 BX_CPU_C::set_ZF(Boolean val) {
     BX_CPU_THIS_PTR lf_flags_status &= 0xff0fff;
     BX_CPU_THIS_PTR eflags.zf = val;
     }
 
-    BX_CPP_INLINE void
+    inline void
 BX_CPU_C::set_SF(Boolean val) {
     BX_CPU_THIS_PTR lf_flags_status &= 0xf0ffff;
     BX_CPU_THIS_PTR eflags.sf = val;
     }
 
 
-    BX_CPP_INLINE void
+    inline void
 BX_CPU_C::set_OF(Boolean val) {
     BX_CPU_THIS_PTR lf_flags_status &= 0x0fffff;
     BX_CPU_THIS_PTR eflags.of = val;
     }
 
-    BX_CPP_INLINE void
+    inline void
 BX_CPU_C::set_PF(Boolean val) {
     BX_CPU_THIS_PTR lf_flags_status &= 0xffff0f;
     BX_CPU_THIS_PTR lf_pf = val;
     }
 
-    BX_CPP_INLINE void
+    inline void
 BX_CPU_C::set_PF_base(Bit8u val) {
     BX_CPU_THIS_PTR eflags.pf_byte = val;
     BX_CPU_THIS_PTR lf_flags_status = (BX_CPU_THIS_PTR lf_flags_status & 0xffff0f) | BX_LF_MASK_P;
