@@ -1,8 +1,4 @@
-/////////////////////////////////////////////////////////////////////////
-// $Id: debug.h,v 1.11 2002/03/12 09:16:41 bdenney Exp $
-/////////////////////////////////////////////////////////////////////////
-//
-//  Copyright (C) 2001  MandrakeSoft S.A.
+//  Copyright (C) 2000  MandrakeSoft S.A.
 //
 //    MandrakeSoft S.A.
 //    43, rue d'Aboukir
@@ -26,8 +22,9 @@
 
 
 // if including from C parser, need basic types etc
+#ifndef __cplusplus
 #include "config.h"
-#include "osdep.h"
+#endif
 
 #if BX_USE_LOADER
 #include "loader_misc.h"
@@ -45,7 +42,7 @@ void bx_dbg_loader(char *path, bx_loader_misc_t *misc_ptr);
 
 #define BX_DBG_NO_HANDLE 1000
 
-extern Bit32u dbg_cpu;
+
 
 unsigned long crc32(unsigned char *buf, int len);
 
@@ -66,19 +63,10 @@ void bx_add_lex_input(char *buf);
 extern int bxparse(void);
 extern void bxerror(char *s);
 
-typedef struct {
-  Bit64s from;
-  Bit64s to;
-} bx_num_range;
-#define EMPTY_ARG (-1)
-
-bx_num_range make_num_range (Bit64s from, Bit64s to);
 char* bx_dbg_symbolic_address(Bit32u context, Bit32u eip, Bit32u base);
 void bx_dbg_symbol_command(char* filename, Boolean global, Bit32u offset);
 void bx_dbg_trace_on_command(void);
 void bx_dbg_trace_off_command(void);
-void bx_dbg_trace_reg_on_command(void);
-void bx_dbg_trace_reg_off_command(void);
 void bx_dbg_ptime_command(void);
 void bx_dbg_timebp_command(Boolean absolute, Bit64u time);
 void bx_dbg_diff_memory(void);
@@ -99,8 +87,8 @@ void bx_dbg_print_string_command(Bit32u addr);
 void bx_dbg_show_command(char*); /* BW */
 void enter_playback_entry();
 void bx_dbg_print_stack_command(int nwords);
-void bx_dbg_watch(int read, Bit32u address);
-void bx_dbg_unwatch(int read, Bit32u address);
+void bx_dbg_watch(Boolean read, Bit32u address);
+void bx_dbg_unwatch(Boolean read, Bit32u address);
 void bx_dbg_continue_command(void);
 void bx_dbg_stepN_command(bx_dbg_icount_t count);
 void bx_dbg_set_command(char *p1, char *p2, char *p3);
@@ -111,16 +99,8 @@ void bx_dbg_pbreakpoint_command(Boolean specific, Bit32u paddress);
 void bx_dbg_info_bpoints_command(void);
 void bx_dbg_quit_command(void);
 void bx_dbg_info_program_command(void);
-#define BX_INFO_CPU_REGS 1   /* choices for bx_dbg_info_registers_command */
-#define BX_INFO_FPU_REGS 2
-void bx_dbg_info_registers_command(int); 
+void bx_dbg_info_registers_command(void);
 void bx_dbg_info_dirty_command(void);
-void bx_dbg_info_idt_command(bx_num_range);
-void bx_dbg_info_gdt_command(bx_num_range);
-void bx_dbg_info_ldt_command(bx_num_range);
-void bx_dbg_info_tss_command(bx_num_range);
-void bx_dbg_info_control_regs_command(void);
-void bx_dbg_info_linux_command(void);
 void bx_dbg_examine_command(char *command, char *format, Boolean format_passed,
                     Bit32u addr, Boolean addr_passed, int simulator);
 void bx_dbg_setpmem_command(Bit32u addr, unsigned len, Bit32u val);
@@ -129,7 +109,7 @@ void bx_dbg_query_command(char *);
 void bx_dbg_take_command(char *, unsigned n);
 void bx_dbg_dump_cpu_command(void);
 void bx_dbg_set_cpu_command(void);
-void bx_dbg_disassemble_command(bx_num_range);
+void bx_dbg_disassemble_command(Bit32u addr1, Bit32u addr2);
 void bx_dbg_instrument_command(char *);
 void bx_dbg_loader_command(char *);
 void bx_dbg_doit_command(unsigned);
@@ -138,8 +118,6 @@ void bx_dbg_maths_command(char *command, int data1, int data2);
 void bx_dbg_maths_expression_command(char *expr);
 void bx_dbg_v2l_command(unsigned seg_no, Bit32u offset);
 extern Boolean watchpoint_continue;
-void bx_dbg_linux_syscall ();
-void bx_dbg_info_ne2k(int page, int reg);
 
 #ifdef __cplusplus
 }
@@ -157,7 +135,7 @@ extern int num_read_watchpoints;
 extern Bit32u read_watchpoint[MAX_READ_WATCHPOINTS];
 
 typedef enum {
-      STOP_NO_REASON = 0, STOP_TIME_BREAK_POINT, STOP_READ_WATCH_POINT, STOP_WRITE_WATCH_POINT, STOP_MAGIC_BREAK_POINT, UNUSED_STOP_TRACE, STOP_MODE_BREAK_POINT, STOP_CPU_HALTED
+      STOP_NO_REASON = 0, STOP_TIME_BREAK_POINT, STOP_READ_WATCH_POINT, STOP_WRITE_WATCH_POINT, STOP_MAGIC_BREAK_POINT, STOP_TRACE, STOP_MODE_BREAK_POINT
 } stop_reason_t;
 
 typedef enum {
@@ -257,18 +235,6 @@ typedef struct {
   // user typed Ctrl-C, requesting simulator stop at next convient spot
   volatile Boolean interrupt_requested;
 
-  // when a triple fault occurs, Bochs panics.  If you continue through
-  // the panic, it will generally produce another exception and panic
-  // again at an even deeper stack level.  To recover from this potentially
-  // infinite recursion, I set special_unwind_stack to true.  This causes
-  // the interrupt() and exception() functions to return immediately instead
-  // of creating more exception conditions, and allows the user to reenter the
-  // debugger after the triple fault.  Note that special_unwind_stack causes
-  // bochs to NOT emulate the hardware behavior correctly.  The correct
-  // behavior would be to reboot.  (Rebooting, if it is ever implemented,
-  // will need some kind of unwinding too.)
-  Boolean special_unwind_stack;
-
   // booleans to control whether simulator should report events
   // to debug controller
   struct {
@@ -304,7 +270,7 @@ typedef struct {
 
 // working information for each simulator to update when a guard
 // is reached (found)
-typedef struct bx_guard_found_t {
+typedef struct {
   unsigned long guard_found;
   unsigned iaddr_index;
   bx_dbg_icount_t icount; // number of completed instructions
@@ -316,6 +282,7 @@ typedef struct bx_guard_found_t {
   } bx_guard_found_t;
 
 extern bx_guard_t        bx_guard;
+extern bx_guard_found_t  bx_guard_found[];
 
 
 
@@ -401,7 +368,6 @@ typedef struct {
                    Bit32u addr1, Bit32u addr2, Bit32u *crc);
   } bx_dbg_callback_t;
 
-extern bx_dbg_callback_t bx_dbg_callback[BX_NUM_SIMULATORS];
 
 void BX_SIM1_INIT(bx_dbg_callback_t *, int argc, char *argv[]);
 #ifdef BX_SIM2_INIT
@@ -424,7 +390,6 @@ void    bx_dbg_outp(Bit16u addr, Bit32u value, unsigned len);
 void    bx_dbg_raise_HLDA(void);
 Bit8u   bx_dbg_IAC(void);
 void    bx_dbg_set_INTR(Boolean b);
-void bx_dbg_disassemble_current (int which_cpu, int print_time);
 
 int bx_dbg_symbolic_output(void); /* BW */
 #endif // #ifdef __cplusplus
