@@ -1,6 +1,5 @@
 /*---------------------------------------------------------------------------+
  |  errors.c                                                                 |
- |  $Id: errors.c,v 1.15.2.1 2004/02/06 22:14:35 danielg4 Exp $
  |                                                                           |
  |  The error handling functions for wm-FPU-emu                              |
  |                                                                           |
@@ -19,7 +18,8 @@
  +---------------------------------------------------------------------------*/
 
 #include <linux/signal.h>
-#include <stdio.h>
+
+#include <asm/uaccess.h>
 
 #include "fpu_emu.h"
 #include "fpu_system.h"
@@ -28,10 +28,50 @@
 #include "control_w.h"
 #include "reg_constant.h"
 #include "version.h"
-#ifdef __cplusplus
-extern "C"
+
+/* */
+#undef PRINT_MESSAGES
+/* */
+
+
+#ifndef USE_WITH_CPU_SIM
+void Un_impl(void)
+{
+  u_char byte1, FPU_modrm;
+  u32 address = FPU_ORIG_EIP;
+
+  RE_ENTRANT_CHECK_OFF;
+  /* No need to verify_area(), we have previously fetched these bytes. */
+  printk("Unimplemented FPU Opcode at eip=%p : ", (void *) address);
+  if ( FPU_CS == __USER_CS )
+    {
+      while ( 1 )
+	{
+	  FPU_get_user(byte1, (u_char *) address);
+	  if ( (byte1 & 0xf8) == 0xd8 ) break;
+	  printk("[%02x]", byte1);
+	  address++;
+	}
+      printk("%02x ", byte1);
+      FPU_get_user(FPU_modrm, 1 + (u_char *) address);
+      
+      if (FPU_modrm >= 0300)
+	printk("%02x (%02x+%d)\n", FPU_modrm, FPU_modrm & 0xf8, FPU_modrm & 7);
+      else
+	printk("/%d\n", (FPU_modrm >> 3) & 7);
+    }
+  else
+    {
+      printk("cs selector = %04x\n", FPU_CS);
+    }
+
+  RE_ENTRANT_CHECK_ON;
+
+  EXCEPTION(EX_Invalid);
+
+}
 #endif
-int printk(const char * fmt, ...);
+
 
 /*
    Called for opcodes which are illegal and which are known to result in a
@@ -39,39 +79,79 @@ int printk(const char * fmt, ...);
    */
 void FPU_illegal(void)
 {
-  math_abort(NULL, SIGILL);
+  math_abort(FPU_info,SIGILL);
 }
 
+
+
 #ifndef USE_WITH_CPU_SIM
 void FPU_printall(void)
 {
   int i;
   static const char *tag_desc[] = { "Valid", "Zero", "ERROR", "Empty",
                               "DeNorm", "Inf", "NaN" };
+  u_char byte1, FPU_modrm;
+  u32 address = FPU_ORIG_EIP;
+
+  RE_ENTRANT_CHECK_OFF;
+  /* No need to verify_area(), we have previously fetched these bytes. */
+  printk("At %p:", (void *) address);
+  if ( FPU_CS == __USER_CS )
+    {
+#define MAX_PRINTED_BYTES 20
+      for ( i = 0; i < MAX_PRINTED_BYTES; i++ )
+	{
+	  FPU_get_user(byte1, (u_char *) address);
+	  if ( (byte1 & 0xf8) == 0xd8 )
+	    {
+	      printk(" %02x", byte1);
+	      break;
+	    }
+	  printk(" [%02x]", byte1);
+	  address++;
+	}
+      if ( i == MAX_PRINTED_BYTES )
+	printk(" [more..]\n");
+      else
+	{
+	  FPU_get_user(FPU_modrm, 1 + (u_char *) address);
+	  
+	  if (FPU_modrm >= 0300)
+	    printk(" %02x (%02x+%d)\n", FPU_modrm, FPU_modrm & 0xf8, FPU_modrm & 7);
+	  else
+	    printk(" /%d, mod=%d rm=%d\n",
+		   (FPU_modrm >> 3) & 7, (FPU_modrm >> 6) & 3, FPU_modrm & 7);
+	}
+    }
+  else
+    {
+      printk("%04x\n", FPU_CS);
+    }
+
+  partial_status = status_word();
 
-  FPU_partial_status = status_word();
 
   printk(" SW: b=%d st=%ld es=%d sf=%d cc=%d%d%d%d ef=%d%d%d%d%d%d\n",
-	 FPU_partial_status & 0x8000 ? 1 : 0,   /* busy */
-	 (FPU_partial_status & 0x3800) >> 11,   /* stack top pointer */
-	 FPU_partial_status & 0x80 ? 1 : 0,     /* Error summary status */
-	 FPU_partial_status & 0x40 ? 1 : 0,     /* Stack flag */
-	 FPU_partial_status & SW_C3?1:0, FPU_partial_status & SW_C2?1:0, /* cc */
-	 FPU_partial_status & SW_C1?1:0, FPU_partial_status & SW_C0?1:0, /* cc */
-	 FPU_partial_status & SW_Precision?1:0, FPU_partial_status & SW_Underflow?1:0,
-	 FPU_partial_status & SW_Overflow?1:0, FPU_partial_status & SW_Zero_Div?1:0,
-	 FPU_partial_status & SW_Denorm_Op?1:0, FPU_partial_status & SW_Invalid?1:0);
+	 partial_status & 0x8000 ? 1 : 0,   /* busy */
+	 (partial_status & 0x3800) >> 11,   /* stack top pointer */
+	 partial_status & 0x80 ? 1 : 0,     /* Error summary status */
+	 partial_status & 0x40 ? 1 : 0,     /* Stack flag */
+	 partial_status & SW_C3?1:0, partial_status & SW_C2?1:0, /* cc */
+	 partial_status & SW_C1?1:0, partial_status & SW_C0?1:0, /* cc */
+	 partial_status & SW_Precision?1:0, partial_status & SW_Underflow?1:0,
+	 partial_status & SW_Overflow?1:0, partial_status & SW_Zero_Div?1:0,
+	 partial_status & SW_Denorm_Op?1:0, partial_status & SW_Invalid?1:0);
   
 printk(" CW: ic=%d rc=%ld%ld pc=%ld%ld iem=%d     ef=%d%d%d%d%d%d\n",
-	 FPU_control_word & 0x1000 ? 1 : 0,
-	 (FPU_control_word & 0x800) >> 11, (FPU_control_word & 0x400) >> 10,
-	 (FPU_control_word & 0x200) >> 9, (FPU_control_word & 0x100) >> 8,
-	 FPU_control_word & 0x80 ? 1 : 0,
-	 FPU_control_word & SW_Precision?1:0, FPU_control_word & SW_Underflow?1:0,
-	 FPU_control_word & SW_Overflow?1:0, FPU_control_word & SW_Zero_Div?1:0,
-	 FPU_control_word & SW_Denorm_Op?1:0, FPU_control_word & SW_Invalid?1:0);
+	 control_word & 0x1000 ? 1 : 0,
+	 (control_word & 0x800) >> 11, (control_word & 0x400) >> 10,
+	 (control_word & 0x200) >> 9, (control_word & 0x100) >> 8,
+	 control_word & 0x80 ? 1 : 0,
+	 control_word & SW_Precision?1:0, control_word & SW_Underflow?1:0,
+	 control_word & SW_Overflow?1:0, control_word & SW_Zero_Div?1:0,
+	 control_word & SW_Denorm_Op?1:0, control_word & SW_Invalid?1:0);
 
-  for (i = 0; i < 8; i++)
+  for ( i = 0; i < 8; i++ )
     {
       FPU_REG *r = &st(i);
       u_char tagi = FPU_gettagi(i);
@@ -117,6 +197,7 @@ static struct {
   { EX_ZeroDiv, "divide by zero" },
   { EX_Denormal, "denormalized operand" },
   { EX_Invalid, "invalid operation" },
+  { EX_INTERNAL, "INTERNAL BUG in "FPU_VERSION },
   { 0, NULL }
 };
 
@@ -169,30 +250,109 @@ static struct {
 	      0x171  in fpu_tags.c
 	      0x172  in fpu_tags.c
 	      0x180  in reg_convert.c
-*/
+       0x2nn  in an *.S file:
+              0x201  in reg_u_add.S
+              0x202  in reg_u_div.S
+              0x203  in reg_u_div.S
+              0x204  in reg_u_div.S
+              0x205  in reg_u_mul.S
+              0x206  in reg_u_sub.S
+              0x207  in wm_sqrt.S
+	      0x208  in reg_div.S
+              0x209  in reg_u_sub.S
+              0x210  in reg_u_sub.S
+              0x211  in reg_u_sub.S
+              0x212  in reg_u_sub.S
+	      0x213  in wm_sqrt.S
+	      0x214  in wm_sqrt.S
+	      0x215  in wm_sqrt.S
+	      0x220  in reg_norm.S
+	      0x221  in reg_norm.S
+	      0x230  in reg_round.S
+	      0x231  in reg_round.S
+	      0x232  in reg_round.S
+	      0x233  in reg_round.S
+	      0x234  in reg_round.S
+	      0x235  in reg_round.S
+	      0x236  in reg_round.S
+	      0x240  in div_Xsig.S
+	      0x241  in div_Xsig.S
+	      0x242  in div_Xsig.S
+ */
 
-void FPU_internal(int type)
+void FPU_exception(int n)
 {
-   printk("FPU emulator: Internal error type 0x%04x\n", type);
+  int i, int_type;
+
+  int_type = 0;         /* Needed only to stop compiler warnings */
+  if ( n & EX_INTERNAL )
+    {
+      int_type = n - EX_INTERNAL;
+      n = EX_INTERNAL;
+      /* Set lots of exception bits! */
+      partial_status |= (SW_Exc_Mask | SW_Summary | SW_Backward);
+    }
+  else
+    {
+      /* Extract only the bits which we use to set the status word */
+      n &= (SW_Exc_Mask);
+      /* Set the corresponding exception bit */
+      partial_status |= n;
+      /* Set summary bits iff exception isn't masked */
+      if ( partial_status & ~control_word & CW_Exceptions )
+	partial_status |= (SW_Summary | SW_Backward);
+      if ( n & (SW_Stack_Fault | EX_Precision) )
+	{
+	  if ( !(n & SW_C1) )
+	    /* This bit distinguishes over- from underflow for a stack fault,
+	       and roundup from round-down for precision loss. */
+	    partial_status &= ~SW_C1;
+	}
+    }
+
+  RE_ENTRANT_CHECK_OFF;
+  if ( (~control_word & n & CW_Exceptions) || (n == EX_INTERNAL) )
+    {
+#ifdef PRINT_MESSAGES
+      /* My message from the sponsor */
+      printk(FPU_VERSION" "__DATE__" (C) W. Metzenthen.\n");
+#endif PRINT_MESSAGES
+      
+      /* Get a name string for error reporting */
+      for (i=0; exception_names[i].type; i++)
+	if ( (exception_names[i].type & n) == exception_names[i].type )
+	  break;
+      
+      if (exception_names[i].type)
+	{
+#ifdef PRINT_MESSAGES
+	  printk("FP Exception: %s!\n", exception_names[i].name);
+#endif PRINT_MESSAGES
+	}
+      else
+	printk("FPU emulator: Unknown Exception: 0x%04x!\n", n);
+      
+      if ( n == EX_INTERNAL )
+	{
+	  printk("FPU emulator: Internal error type 0x%04x\n", int_type);
+	  FPU_printall();
+	}
+#ifdef PRINT_MESSAGES
+      else
+	FPU_printall();
+#endif PRINT_MESSAGES
+
+      /*
+       * The 80486 generates an interrupt on the next non-control FPU
+       * instruction. So we need some means of flagging it.
+       * We use the ES (Error Summary) bit for this.
+       */
+    }
+  RE_ENTRANT_CHECK_ON;
+
+
 }
 
-void FPU_exception(int exception)
-{
-  /* Extract only the bits which we use to set the status word */
-  exception &= (SW_Exc_Mask);
-  /* Set the corresponding exception bit */
-  FPU_partial_status |= exception;
-  /* Set summary bits iff exception isn't masked */
-  if (FPU_partial_status & ~FPU_control_word & CW_Exceptions)
-	FPU_partial_status |= (SW_Summary | SW_Backward);
-  if (exception & (SW_Stack_Fault | EX_Precision))
-  {
-      if (!(exception & SW_C1))
-        /* This bit distinguishes over- from underflow for a stack fault,
-             and roundup from round-down for precision loss. */
-        FPU_partial_status &= ~SW_C1;
-  }
-}
 
 /* Real operation attempted on a NaN. */
 /* Returns < 0 if the exception is unmasked */
@@ -206,25 +366,25 @@ int real_1op_NaN(FPU_REG *a)
      differ) is chosen to reproduce 80486 behaviour */
   signalling = isNaN && !(a->sigh & 0x40000000);
 
-  if (!signalling)
+  if ( !signalling )
     {
-      if (!isNaN)  /* pseudo-NaN, or other unsupported? */
+      if ( !isNaN )  /* pseudo-NaN, or other unsupported? */
 	{
-	  if (FPU_control_word & CW_Invalid)
+	  if ( control_word & CW_Invalid )
 	    {
 	      /* Masked response */
 	      reg_copy(&CONST_QNaN, a);
 	    }
 	  EXCEPTION(EX_Invalid);
-	  return (!(FPU_control_word & CW_Invalid) ? FPU_Exception : 0) | TAG_Special;
+	  return (!(control_word & CW_Invalid) ? FPU_Exception : 0) | TAG_Special;
 	}
       return TAG_Special;
     }
 
-  if (FPU_control_word & CW_Invalid)
+  if ( control_word & CW_Invalid )
     {
       /* The masked response */
-      if (!(a->sigh & 0x80000000))  /* pseudo-NaN ? */
+      if ( !(a->sigh & 0x80000000) )  /* pseudo-NaN ? */
 	{
 	  reg_copy(&CONST_QNaN, a);
 	}
@@ -234,7 +394,7 @@ int real_1op_NaN(FPU_REG *a)
 
   EXCEPTION(EX_Invalid);
 
-  return (!(FPU_control_word & CW_Invalid) ? FPU_Exception : 0) | TAG_Special;
+  return (!(control_word & CW_Invalid) ? FPU_Exception : 0) | TAG_Special;
 }
 
 
@@ -250,9 +410,9 @@ int real_2op_NaN(FPU_REG const *b, u_char tagb,
   FPU_REG const *x;
   int signalling, unsupported;
 
-  if (taga == TAG_Special)
+  if ( taga == TAG_Special )
     taga = FPU_Special(a);
-  if (tagb == TAG_Special)
+  if ( tagb == TAG_Special )
     tagb = FPU_Special(b);
 
   /* TW_NaN is also used for unsupported data types. */
@@ -260,15 +420,15 @@ int real_2op_NaN(FPU_REG const *b, u_char tagb,
 		 && !((exponent(a) == EXP_OVER) && (a->sigh & 0x80000000)))
     || ((tagb == TW_NaN)
 	&& !((exponent(b) == EXP_OVER) && (b->sigh & 0x80000000)));
-  if (unsupported)
+  if ( unsupported )
     {
-      if (FPU_control_word & CW_Invalid)
+      if ( control_word & CW_Invalid )
 	{
 	  /* Masked response */
 	  FPU_copy_to_regi(&CONST_QNaN, TAG_Special, deststnr);
 	}
       EXCEPTION(EX_Invalid);
-      return (!(FPU_control_word & CW_Invalid) ? FPU_Exception : 0) | TAG_Special;
+      return (!(control_word & CW_Invalid) ? FPU_Exception : 0) | TAG_Special;
     }
 
   if (taga == TW_NaN)
@@ -277,9 +437,9 @@ int real_2op_NaN(FPU_REG const *b, u_char tagb,
       if (tagb == TW_NaN)
 	{
 	  signalling = !(a->sigh & b->sigh & 0x40000000);
-	  if (significand(b) > significand(a))
+	  if ( significand(b) > significand(a) )
 	    x = b;
-	  else if (significand(b) == significand(a))
+	  else if ( significand(b) == significand(a) )
 	    {
 	      /* The default result for the case of two "equal" NaNs (signs may
 		 differ) is chosen to reproduce 80486 behaviour */
@@ -295,7 +455,7 @@ int real_2op_NaN(FPU_REG const *b, u_char tagb,
   else
 #ifdef PARANOID
     if (tagb == TW_NaN)
-#endif /* PARANOID */
+#endif PARANOID
     {
       signalling = !(b->sigh & 0x40000000);
       x = b;
@@ -304,22 +464,22 @@ int real_2op_NaN(FPU_REG const *b, u_char tagb,
   else
     {
       signalling = 0;
-      INTERNAL(0x113);
+      EXCEPTION(EX_INTERNAL|0x113);
       x = &CONST_QNaN;
     }
-#endif /* PARANOID */
+#endif PARANOID
 
-  if ((!signalling) || (FPU_control_word & CW_Invalid))
+  if ( (!signalling) || (control_word & CW_Invalid) )
     {
-      if (! x)
+      if ( ! x )
 	x = b;
 
-      if (!(x->sigh & 0x80000000))  /* pseudo-NaN ? */
+      if ( !(x->sigh & 0x80000000) )  /* pseudo-NaN ? */
 	x = &CONST_QNaN;
 
       FPU_copy_to_regi(x, TAG_Special, deststnr);
 
-      if (!signalling)
+      if ( !signalling )
 	return TAG_Special;
 
       /* ensure a Quiet NaN */
@@ -328,7 +488,7 @@ int real_2op_NaN(FPU_REG const *b, u_char tagb,
 
   EXCEPTION(EX_Invalid);
 
-  return (!(FPU_control_word & CW_Invalid) ? FPU_Exception : 0) | TAG_Special;
+  return (!(control_word & CW_Invalid) ? FPU_Exception : 0) | TAG_Special;
 }
 
 
@@ -336,15 +496,17 @@ int real_2op_NaN(FPU_REG const *b, u_char tagb,
 /* Returns < 0 if the exception is unmasked */
 asmlinkage int arith_invalid(int deststnr)
 {
+
   EXCEPTION(EX_Invalid);
   
-  if (FPU_control_word & CW_Invalid)
+  if ( control_word & CW_Invalid )
     {
       /* The masked response */
       FPU_copy_to_regi(&CONST_QNaN, TAG_Special, deststnr);
     }
   
-  return (!(FPU_control_word & CW_Invalid) ? FPU_Exception : 0) | TAG_Valid;
+  return (!(control_word & CW_Invalid) ? FPU_Exception : 0) | TAG_Valid;
+
 }
 
 
@@ -354,7 +516,7 @@ asmlinkage int FPU_divide_by_zero(int deststnr, u_char sign)
   FPU_REG *dest = &st(deststnr);
   int tag = TAG_Valid;
 
-  if (FPU_control_word & CW_ZeroDiv)
+  if ( control_word & CW_ZeroDiv )
     {
       /* The masked response */
       FPU_copy_to_regi(&CONST_INF, TAG_Special, deststnr);
@@ -364,17 +526,18 @@ asmlinkage int FPU_divide_by_zero(int deststnr, u_char sign)
  
   EXCEPTION(EX_ZeroDiv);
 
-  return (!(FPU_control_word & CW_ZeroDiv) ? FPU_Exception : 0) | tag;
+  return (!(control_word & CW_ZeroDiv) ? FPU_Exception : 0) | tag;
+
 }
 
 
 /* This may be called often, so keep it lean */
 int set_precision_flag(int flags)
 {
-  if (FPU_control_word & CW_Precision)
+  if ( control_word & CW_Precision )
     {
-      FPU_partial_status &= ~(SW_C1 & flags);
-      FPU_partial_status |= flags;   /* The masked response */
+      partial_status &= ~(SW_C1 & flags);
+      partial_status |= flags;   /* The masked response */
       return 0;
     }
   else
@@ -388,8 +551,8 @@ int set_precision_flag(int flags)
 /* This may be called often, so keep it lean */
 asmlinkage void set_precision_flag_up(void)
 {
-  if (FPU_control_word & CW_Precision)
-    FPU_partial_status |= (SW_Precision | SW_C1);   /* The masked response */
+  if ( control_word & CW_Precision )
+    partial_status |= (SW_Precision | SW_C1);   /* The masked response */
   else
     EXCEPTION(EX_Precision | SW_C1);
 }
@@ -398,10 +561,10 @@ asmlinkage void set_precision_flag_up(void)
 /* This may be called often, so keep it lean */
 asmlinkage void set_precision_flag_down(void)
 {
-  if (FPU_control_word & CW_Precision)
+  if ( control_word & CW_Precision )
     {   /* The masked response */
-      FPU_partial_status &= ~SW_C1;
-      FPU_partial_status |= SW_Precision;
+      partial_status &= ~SW_C1;
+      partial_status |= SW_Precision;
     }
   else
     EXCEPTION(EX_Precision);
@@ -410,9 +573,9 @@ asmlinkage void set_precision_flag_down(void)
 
 asmlinkage int denormal_operand(void)
 {
-  if (FPU_control_word & CW_Denormal)
+  if ( control_word & CW_Denormal )
     {   /* The masked response */
-      FPU_partial_status |= SW_Denorm_Op;
+      partial_status |= SW_Denorm_Op;
       return TAG_Special;
     }
   else
@@ -427,7 +590,7 @@ asmlinkage int arith_overflow(FPU_REG *dest)
 {
   int tag = TAG_Valid;
 
-  if (FPU_control_word & CW_Overflow)
+  if ( control_word & CW_Overflow )
     {
       /* The masked response */
       reg_copy(&CONST_INF, dest);
@@ -440,7 +603,7 @@ asmlinkage int arith_overflow(FPU_REG *dest)
     }
 
   EXCEPTION(EX_Overflow);
-  if (FPU_control_word & CW_Overflow)
+  if ( control_word & CW_Overflow )
     {
       /* The overflow exception is masked. */
       /* By definition, precision is lost.
@@ -451,6 +614,7 @@ asmlinkage int arith_overflow(FPU_REG *dest)
     }
 
   return tag;
+
 }
 
 
@@ -459,11 +623,11 @@ asmlinkage int arith_round_overflow(FPU_REG *dest, u8 sign)
   int tag = TAG_Valid;
   int largest;
 
-  if (FPU_control_word & CW_Overflow)
+  if ( control_word & CW_Overflow )
     {
       /* The masked response */
       /* The response here depends upon the rounding mode */
-      switch (FPU_control_word & CW_RC)
+      switch ( control_word & CW_RC )
 	{
 	case RC_CHOP:		/* Truncate */
 	  largest = 1;
@@ -478,7 +642,7 @@ asmlinkage int arith_round_overflow(FPU_REG *dest, u8 sign)
 	  largest = 0;
 	  break;
 	}
-      if (! largest)
+      if ( ! largest )
 	{
 	  reg_copy(&CONST_INF, dest);
 	  tag = TAG_Special;
@@ -486,17 +650,17 @@ asmlinkage int arith_round_overflow(FPU_REG *dest, u8 sign)
       else
 	{
 	  dest->exp = EXTENDED_Ebias+EXP_OVER-1;
-	  switch (FPU_control_word & CW_PC)
+	  switch ( control_word & CW_PC )
 	    {
 	    case 01:
 	    case PR_64_BITS:
-	      significand(dest) = BX_CONST64(0xffffffffffffffff);
+	      significand(dest) = 0xffffffffffffffffLL;
 	      break;
 	    case PR_53_BITS:
-	      significand(dest) = BX_CONST64(0xfffffffffffff800);
+	      significand(dest) = 0xfffffffffffff800LL;
 	      break;
 	    case PR_24_BITS:
-	      significand(dest) = BX_CONST64(0xffffff0000000000);
+	      significand(dest) = 0xffffff0000000000LL;
 	      break;
 	    }
 	}
@@ -509,10 +673,10 @@ asmlinkage int arith_round_overflow(FPU_REG *dest, u8 sign)
     }
 
   EXCEPTION(EX_Overflow);
-  if (FPU_control_word & CW_Overflow)
+  if ( control_word & CW_Overflow )
     {
       /* The overflow exception is masked. */
-      if (largest)
+      if ( largest )
 	{
 	  EXCEPTION(EX_Precision);
 	}
@@ -527,6 +691,7 @@ asmlinkage int arith_round_overflow(FPU_REG *dest, u8 sign)
     }
 
   return tag;
+
 }
 
 
@@ -534,13 +699,13 @@ asmlinkage int arith_underflow(FPU_REG *dest)
 {
   int tag = TAG_Valid;
 
-  if (FPU_control_word & CW_Underflow)
+  if ( control_word & CW_Underflow )
     {
       /* The masked response */
-      if (exponent16(dest) <= EXP_UNDER - 63)
+      if ( exponent16(dest) <= EXP_UNDER - 63 )
 	{
 	  reg_copy(&CONST_Z, dest);
-	  FPU_partial_status &= ~SW_C1;       /* Round down. */
+	  partial_status &= ~SW_C1;       /* Round down. */
 	  tag = TAG_Zero;
 	}
       else
@@ -555,7 +720,7 @@ asmlinkage int arith_underflow(FPU_REG *dest)
     }
 
   EXCEPTION(EX_Underflow);
-  if (FPU_control_word & CW_Underflow)
+  if ( control_word & CW_Underflow )
     {
       /* The underflow exception is masked. */
       EXCEPTION(EX_Precision);
@@ -563,49 +728,63 @@ asmlinkage int arith_underflow(FPU_REG *dest)
     }
 
   return tag;
+
 }
 
 
 void FPU_stack_overflow(void)
 {
- if (FPU_control_word & CW_Invalid)
+
+ if ( control_word & CW_Invalid )
     {
       /* The masked response */
-      FPU_tos--;
+      top--;
       FPU_copy_to_reg0(&CONST_QNaN, TAG_Special);
     }
 
   EXCEPTION(EX_StackOver);
+
+  return;
+
 }
 
 
 void FPU_stack_underflow(void)
 {
- if (FPU_control_word & CW_Invalid)
+
+ if ( control_word & CW_Invalid )
     {
       /* The masked response */
       FPU_copy_to_reg0(&CONST_QNaN, TAG_Special);
     }
 
   EXCEPTION(EX_StackUnder);
+
+  return;
+
 }
 
 
 void FPU_stack_underflow_i(int i)
 {
- if (FPU_control_word & CW_Invalid)
+
+ if ( control_word & CW_Invalid )
     {
       /* The masked response */
       FPU_copy_to_regi(&CONST_QNaN, TAG_Special, i);
     }
 
   EXCEPTION(EX_StackUnder);
+
+  return;
+
 }
 
 
 void FPU_stack_underflow_pop(int i)
 {
- if (FPU_control_word & CW_Invalid)
+
+ if ( control_word & CW_Invalid )
     {
       /* The masked response */
       FPU_copy_to_regi(&CONST_QNaN, TAG_Special, i);
@@ -613,4 +792,8 @@ void FPU_stack_underflow_pop(int i)
     }
 
   EXCEPTION(EX_StackUnder);
+
+  return;
+
 }
+
