@@ -1,6 +1,5 @@
 /*---------------------------------------------------------------------------+
  |  poly.h                                                                   |
- |  $Id: poly.h,v 1.5.8.1 2004/02/10 00:21:49 danielg4 Exp $
  |                                                                           |
  |  Header file for the FPU-emu poly*.c source files.                        |
  |                                                                           |
@@ -21,9 +20,6 @@
    Intended to be used to get results better than 8-byte computation
    allows. 9-byte would probably be sufficient.
    */
-#if defined(__MWERKS__) && defined(macintosh)
-#pragma options align=packed
-#endif
 typedef struct {
 #ifdef EMU_BIG_ENDIAN
   u32 msw;
@@ -34,10 +30,7 @@ typedef struct {
   u32 midw;
   u32 msw;
 #endif
-} GCC_ATTRIBUTE((packed)) Xsig;
-#if defined(__MWERKS__) && defined(macintosh)
-#pragma options align=reset
-#endif
+} __attribute__ ((packed)) Xsig;
 
 asmlinkage void mul64(u64 const *a, u64 const *b,
 		      u64 *result);
@@ -81,9 +74,8 @@ asmlinkage void div_Xsig(const Xsig *x1, const Xsig *x2, Xsig *dest);
    */
 
 /* Multiply two fixed-point 32 bit numbers, producing a 32 bit result.
-   The answer is the ms word of the product.  */
-BX_C_INLINE
-u32 mul_32_32(const u32 arg1, const u32 arg2)
+   The answer is the ms word of the product. */
+extern inline u32 mul_32_32(const u32 arg1, const u32 arg2)
 {
 #ifdef NO_ASSEMBLER
   return (((u64)arg1) * arg2) >> 32;
@@ -102,8 +94,7 @@ u32 mul_32_32(const u32 arg1, const u32 arg2)
 
 
 /* Add the 12 byte Xsig x2 to Xsig dest, with no checks for overflow. */
-BX_C_INLINE
-void add_Xsig_Xsig(Xsig *dest, const Xsig *x2)
+extern inline void add_Xsig_Xsig(Xsig *dest, const Xsig *x2)
 {
 #ifdef NO_ASSEMBLER
   dest->lsw += x2->lsw;
@@ -120,10 +111,10 @@ void add_Xsig_Xsig(Xsig *dest, const Xsig *x2)
     }
   dest->msw += x2->msw;
 #else
-  asm volatile ("movl %1,%%edi; movl %2,%%esi; "
-                "movl (%%esi),%%eax; addl %%eax,(%%edi); "
-                "movl 4(%%esi),%%eax; adcl %%eax,4(%%edi); "
-                "movl 8(%%esi),%%eax; adcl %%eax,8(%%edi);"
+  asm volatile ("movl %1,%%edi; movl %2,%%esi;
+                 movl (%%esi),%%eax; addl %%eax,(%%edi);
+                 movl 4(%%esi),%%eax; adcl %%eax,4(%%edi);
+                 movl 8(%%esi),%%eax; adcl %%eax,8(%%edi);"
                  :"=g" (*dest):"g" (dest), "g" (x2)
                  :"ax","si","di");
 #endif
@@ -131,8 +122,7 @@ void add_Xsig_Xsig(Xsig *dest, const Xsig *x2)
 
 
 /* Add the 12 byte Xsig x2 to Xsig dest, adjust exp if overflow occurs. */
-BX_C_INLINE
-void add_two_Xsig(Xsig *dest, const Xsig *x2, s32 *exp)
+extern inline void add_two_Xsig(Xsig *dest, const Xsig *x2, s32 *exp)
 {
 #ifdef NO_ASSEMBLER
   int ovfl = 0;
@@ -174,16 +164,16 @@ void add_two_Xsig(Xsig *dest, const Xsig *x2, s32 *exp)
 /* Note: the constraints in the asm statement didn't always work properly
    with gcc 2.5.8.  Changing from using edi to using ecx got around the
    problem, but keep fingers crossed! */
-  asm volatile ("movl %2,%%ecx; movl %3,%%esi; "
-                "movl (%%esi),%%eax; addl %%eax,(%%ecx); "
-                "movl 4(%%esi),%%eax; adcl %%eax,4(%%ecx); "
-                "movl 8(%%esi),%%eax; adcl %%eax,8(%%ecx); "
-                "jnc 0f; "
-		"rcrl 8(%%ecx); rcrl 4(%%ecx); rcrl (%%ecx); "
-                "movl %4,%%ecx; incl (%%ecx); "
-                "movl $1,%%eax; jmp 1f; "
-                "0: xorl %%eax,%%eax; "
-                " 1:"
+  asm volatile ("movl %2,%%ecx; movl %3,%%esi;
+                 movl (%%esi),%%eax; addl %%eax,(%%ecx);
+                 movl 4(%%esi),%%eax; adcl %%eax,4(%%ecx);
+                 movl 8(%%esi),%%eax; adcl %%eax,8(%%ecx);
+                 jnc 0f;
+		 rcrl 8(%%ecx); rcrl 4(%%ecx); rcrl (%%ecx)
+                 movl %4,%%ecx; incl (%%ecx)
+                 movl $1,%%eax; jmp 1f;
+                 0: xorl %%eax,%%eax;
+                 1:"
 		:"=g" (*exp), "=g" (*dest)
 		:"g" (dest), "g" (x2), "g" (exp)
 		:"cx","si","ax");
@@ -192,8 +182,7 @@ void add_two_Xsig(Xsig *dest, const Xsig *x2, s32 *exp)
 
 
 /* Negate the 12 byte Xsig */
-BX_C_INLINE
-void negate_Xsig(Xsig *x)
+extern inline void negate_Xsig(Xsig *x)
 {
 #ifdef NO_ASSEMBLER
   x->lsw = ~x->lsw;
@@ -219,4 +208,4 @@ void negate_Xsig(Xsig *x)
 }
 
 
-#endif /* _POLY_H */
+#endif _POLY_H
