@@ -1,6 +1,5 @@
 /*---------------------------------------------------------------------------+
  |  poly_2xm1.c                                                              |
- |  $Id: poly_2xm1.c,v 1.6 2003/10/05 12:26:11 sshwarts Exp $
  |                                                                           |
  | Function to compute 2^x-1 by a polynomial approximation.                  |
  |                                                                           |
@@ -22,17 +21,17 @@
 #define	HIPOWER	11
 static const u64 lterms[HIPOWER] =
 {
-  BX_CONST64(0x0000000000000000),  /* This term done separately as 12 bytes */
-  BX_CONST64(0xf5fdeffc162c7543),
-  BX_CONST64(0x1c6b08d704a0bfa6),
-  BX_CONST64(0x0276556df749cc21),
-  BX_CONST64(0x002bb0ffcf14f6b8),
-  BX_CONST64(0x0002861225ef751c),
-  BX_CONST64(0x00001ffcbfcd5422),
-  BX_CONST64(0x00000162c005d5f1),
-  BX_CONST64(0x0000000da96ccb1b),
-  BX_CONST64(0x0000000078d1b897),
-  BX_CONST64(0x000000000422b029)
+  0x0000000000000000LL,  /* This term done separately as 12 bytes */
+  0xf5fdeffc162c7543LL,
+  0x1c6b08d704a0bfa6LL,
+  0x0276556df749cc21LL,
+  0x002bb0ffcf14f6b8LL,
+  0x0002861225ef751cLL,
+  0x00001ffcbfcd5422LL,
+  0x00000162c005d5f1LL,
+  0x0000000da96ccb1bLL,
+  0x0000000078d1b897LL,
+  0x000000000422b029LL
 };
 
 static const Xsig hiterm = MK_XSIG(0xb17217f7, 0xd1cf79ab, 0xc8a39194);
@@ -65,10 +64,10 @@ int	poly_2xm1(u_char sign, FPU_REG *arg, FPU_REG *result)
   if ( exponent >= 0 )    	/* Don't want a |number| >= 1.0 */
     {
       /* Number negative, too large, or not Valid. */
-      INTERNAL(0x127);
+      EXCEPTION(EX_INTERNAL|0x127);
       return 1;
     }
-#endif /* PARANOID */
+#endif PARANOID
 
   argSignif.lsw = 0;
   XSIG_LL(argSignif) = Xll = significand(arg);
@@ -147,7 +146,7 @@ int	poly_2xm1(u_char sign, FPU_REG *arg, FPU_REG *result)
   significand(result) = XSIG_LL(accumulator);
   setexponent16(result, exponent);
 
-  tag = FPU_round(result, 1, FULL_PRECISION, sign);
+  tag = FPU_round(result, 1, 0, FULL_PRECISION, sign);
 
   setsign(result, sign);
   FPU_settag0(tag);
