@@ -1,6 +1,5 @@
 /*---------------------------------------------------------------------------+
  |  poly_l2.c                                                                |
- |  $Id: poly_l2.c,v 1.5 2003/10/05 12:26:11 sshwarts Exp $
  |                                                                           |
  | Compute the base 2 log of a FPU_REG, using a polynomial approximation.    |
  |                                                                           |
@@ -103,7 +102,7 @@ void	poly_l2(FPU_REG *st0_ptr, FPU_REG *st1_ptr, u_char st1_sign)
   significand(st1_ptr) = XSIG_LL(accumulator);
   setexponent16(st1_ptr, expon_expon + exponent16(st1_ptr) + 1);
 
-  tag = FPU_round(st1_ptr, 1, FULL_PRECISION, sign ^ st1_sign);
+  tag = FPU_round(st1_ptr, 1, 0, FULL_PRECISION, sign ^ st1_sign);
   FPU_settagi(1, tag);
 
   set_precision_flag_up();  /* 80486 appears to always do this */
@@ -140,7 +139,7 @@ int	poly_l2p1(u_char sign0, u_char sign1,
       significand(dest) = XSIG_LL(accumulator);
       setexponent16(dest, exponent);
 
-      tag = FPU_round(dest, 1, FULL_PRECISION, sign0 ^ sign1);
+      tag = FPU_round(dest, 1, 0, FULL_PRECISION, sign0 ^ sign1);
       FPU_settagi(1, tag);
 
       if ( tag == TAG_Valid )
@@ -158,7 +157,7 @@ int	poly_l2p1(u_char sign0, u_char sign1,
 #else
 	  if ( arith_invalid(1) < 0 )
 	    return 1;
-#endif /* PECULIAR_486 */
+#endif PECULIAR_486
 	}
 
       /* 80486 appears to do this */
@@ -182,16 +181,16 @@ int	poly_l2p1(u_char sign0, u_char sign1,
 #define	HIPOWER	10
 static const u64 logterms[HIPOWER] =
 {
-  BX_CONST64(0x2a8eca5705fc2ef0),
-  BX_CONST64(0xf6384ee1d01febce),
-  BX_CONST64(0x093bb62877cdf642),
-  BX_CONST64(0x006985d8a9ec439b),
-  BX_CONST64(0x0005212c4f55a9c8),
-  BX_CONST64(0x00004326a16927f0),
-  BX_CONST64(0x0000038d1d80a0e7),
-  BX_CONST64(0x0000003141cc80c6),
-  BX_CONST64(0x00000002b1668c9f),
-  BX_CONST64(0x000000002c7a46aa)
+  0x2a8eca5705fc2ef0LL,
+  0xf6384ee1d01febceLL,
+  0x093bb62877cdf642LL,
+  0x006985d8a9ec439bLL,
+  0x0005212c4f55a9c8LL,
+  0x00004326a16927f0LL,
+  0x0000038d1d80a0e7LL,
+  0x0000003141cc80c6LL,
+  0x00000002b1668c9fLL,
+  0x000000002c7a46aaLL
 };
 
 static const u32 leadterm = 0xb8000000;
@@ -244,7 +243,7 @@ static void log2_kernel(FPU_REG const *arg, u_char argsign, Xsig *accum_result,
 	  /* The argument is too large */
 	}
     }
-#endif /* PECULIAR_486 */
+#endif PECULIAR_486
 
   arg_signif.lsw = argSignif.lsw; XSIG_LL(arg_signif) = XSIG_LL(argSignif);
   adj = norm_Xsig(&argSignif);
