@@ -1,6 +1,5 @@
 /*---------------------------------------------------------------------------+
  |  reg_u_mul.c                                                              |
- |  $Id: reg_u_mul.c,v 1.7 2003/10/05 12:26:11 sshwarts Exp $
  |                                                                           |
  | Core multiplication routine                                               |
  |                                                                           |
@@ -31,9 +30,9 @@ int FPU_u_mul(const FPU_REG *a, const FPU_REG *b, FPU_REG *c, u16 cw,
   u32 lh, ll, th, tl;
 
 #ifdef PARANOID
-  if (! (a->sigh & 0x80000000) || ! (b->sigh & 0x80000000))
+  if ( ! (a->sigh & 0x80000000) || ! (b->sigh & 0x80000000) )
     {
-      INTERNAL(0x205);
+      EXCEPTION(EX_INTERNAL|0x205);
     }
 #endif
 
@@ -50,7 +49,7 @@ int FPU_u_mul(const FPU_REG *a, const FPU_REG *b, FPU_REG *c, u16 cw,
   tl = mi;
   th = mi >> 32;
   lh += tl;
-  if (tl > lh)
+  if ( tl > lh )
     mu ++;
   mu += th;
 
@@ -59,7 +58,7 @@ int FPU_u_mul(const FPU_REG *a, const FPU_REG *b, FPU_REG *c, u16 cw,
   tl = mi;
   th = mi >> 32;
   lh += tl;
-  if (tl > lh)
+  if ( tl > lh )
     mu ++;
   mu += th;
 
@@ -68,20 +67,15 @@ int FPU_u_mul(const FPU_REG *a, const FPU_REG *b, FPU_REG *c, u16 cw,
   ml += ll;
 
   expon -= EXP_BIAS-1;
-  if (expon <= EXP_WAY_UNDER)
+  if ( expon <= EXP_WAY_UNDER )
     expon = EXP_WAY_UNDER;
-    
-  /* if the addition of signed 16-bit values overflowed, substitute
-    the maximum positive exponent to force FPU_round to produce overflow */
-  if (expon > 0x7FFE)
-      expon = 0x7FFE;
 
   c->exp = expon;
 
-  if (! (mu & BX_CONST64(0x8000000000000000)))
+  if ( ! (mu & 0x8000000000000000LL) )
     {
       mu <<= 1;
-      if (ml & BX_CONST64(0x8000000000000000))
+      if ( ml & 0x8000000000000000LL )
 	mu |= 1;
       ml <<= 1;
       c->exp --;
@@ -90,11 +84,12 @@ int FPU_u_mul(const FPU_REG *a, const FPU_REG *b, FPU_REG *c, u16 cw,
   ll = ml;
   lh = ml >> 32;
 
-  if (ll)
+  if ( ll )
     lh |= 1;
 
   c->sigl = mu;
   c->sigh = mu >> 32;
 
-  return FPU_round(c, lh, cw, sign);
+  return FPU_round(c, lh, 0, cw, sign);
+  
 }
