@@ -1,6 +1,5 @@
 /*---------------------------------------------------------------------------+
  |  wm_sqrt.c                                                                |
- |  $Id: wm_sqrt.c,v 1.5 2003/10/05 12:26:11 sshwarts Exp $
  |                                                                           |
  | Fixed point arithmetic square root evaluation.                            |
  |                                                                           |
@@ -35,7 +34,7 @@
 #define ERR_MARGIN 0x20
 
 
-int wm_sqrt(FPU_REG *n, u16 control_w, u8 sign)
+int wm_sqrt(FPU_REG *n, s32 dummy1, s32 dummy2, u16 control_w, u8 sign)
 {
   u64 nn, guess, halfn, lowr, mid, upr, diff, uwork;
   s64 work;
@@ -71,6 +70,7 @@ int wm_sqrt(FPU_REG *n, u16 control_w, u8 sign)
   guess32 = halfn / guess32 + (guess32 >> 1);
   guess32 = halfn / guess32 + (guess32 >> 1);
 
+
 /*
  * Now that an estimate accurate to about 30 bits has been obtained,
  * we improve it to 60 bits or so.
@@ -87,22 +87,23 @@ int wm_sqrt(FPU_REG *n, u16 control_w, u8 sign)
   work += ((u64)guess32) << 32;
 
   if ( work == 0 )  /* This happens in one or two special cases */
-    work = BX_CONST64(0xffffffffffffffff);
+    work = 0xffffffffffffffffLL;
 
   guess = work;
 
   /* guess is now accurate to about 60 bits */
 
+
   if ( work > 0 )
     {
 #ifdef PARANOID
       if ( (n->sigh != 0xffffffff) && (n->sigl != 0xffffffff) )
 	{
-	  INTERNAL(0x213);
+	  EXCEPTION(EX_INTERNAL|0x213);
 	}
 #endif
       /* We know the answer here. */
-      return FPU_round(n, 0x7fffffff, control_w, sign);
+      return FPU_round(n, 0x7fffffff, 0, control_w, sign);
     }
 
   /* Refine the guess to significantly more than 64 bits. */
@@ -153,7 +154,7 @@ int wm_sqrt(FPU_REG *n, u16 control_w, u8 sign)
 #ifdef PARANOID
       if ( (diff >> 32) != 0 )
 	{
-	  INTERNAL(0x207);
+	  EXCEPTION(EX_INTERNAL|0x207);
 	}
 #endif
 
@@ -204,6 +205,7 @@ int wm_sqrt(FPU_REG *n, u16 control_w, u8 sign)
       /* The guess should now be good to about 90 bits */
     }
 
+
   setexponent16(n, 0);
 
   if ( guess32 >= (u32) -ERR_MARGIN )
@@ -217,7 +219,7 @@ int wm_sqrt(FPU_REG *n, u16 control_w, u8 sign)
     {
       /* We have enough accuracy to decide rounding */
       significand(n) = guess;
-      return FPU_round(n, guess32, control_w, sign);
+      return FPU_round(n, guess32, 0, control_w, sign);
     }
 
   if ( (guess32 <= ERR_MARGIN) || (guess32 >= (u32) -ERR_MARGIN) )
@@ -252,7 +254,7 @@ int wm_sqrt(FPU_REG *n, u16 control_w, u8 sign)
 #ifdef PARANOID
       if ( ((s32)work32 > 3*ERR_MARGIN) || ((s32)work32 < -3*ERR_MARGIN) )
 	{
-	  INTERNAL(0x214);
+	  EXCEPTION(EX_INTERNAL|0x214);
 	}
 #endif
 
@@ -261,29 +263,31 @@ int wm_sqrt(FPU_REG *n, u16 control_w, u8 sign)
 	{
 	  /* guess is too large */
 	  significand(n) --;
-	  return FPU_round(n, 0xffffff00, control_w, sign);
+	  return FPU_round(n, 0xffffff00, 0, control_w, sign);
 	}
       else if ( (s32)work32 < 0 )
 	{
 	  /* guess is a little too small */
-	  return FPU_round(n, 0x000000ff, control_w, sign);
+	  return FPU_round(n, 0x000000ff, 0, control_w, sign);
 	}
 
       else if ( (u32)lowr != 0 )
        {
+
          /* guess is too large */
          significand(n) --;
-         return FPU_round(n, 0xffffff00, control_w, sign);
+         return FPU_round(n, 0xffffff00, 0, control_w, sign);
        }
 
       /* Our guess is precise. */
-      return FPU_round(n, 0, control_w, sign);
+      return FPU_round(n, 0, 0, control_w, sign);
     }
 
   /* Very similar to the case above, but the last bit is near 0.5.
      We handle this just like the case above but we shift everything
      by one bit. */
 
+
   uwork = guess;
   uwork <<= 1;
   uwork |= 1;      /* add the half bit */
@@ -310,7 +314,7 @@ int wm_sqrt(FPU_REG *n, u16 control_w, u8 sign)
 #ifdef PARANOID
   if ( ((s32)work32 > 4*3*ERR_MARGIN) || ((s32)work32 < -4*3*ERR_MARGIN) )
     {
-      INTERNAL(0x215);
+      EXCEPTION(EX_INTERNAL|0x215);
     }
 #endif
 
@@ -318,12 +322,12 @@ int wm_sqrt(FPU_REG *n, u16 control_w, u8 sign)
   if ( (s32)work32 < 0 )
     {
       /* guess plus half bit is a little too small */
-      return FPU_round(n, 0x800000ff, control_w, sign);
+      return FPU_round(n, 0x800000ff, 0, control_w, sign);
     }
   else /* Note that the lower 64 bits of the product are not all zero */
     {
       /* guess plus half bit is too large */
-      return FPU_round(n, 0x7fffff00, control_w, sign);
+      return FPU_round(n, 0x7fffff00, 0, control_w, sign);
     }
 
   /*
@@ -333,3 +337,4 @@ int wm_sqrt(FPU_REG *n, u16 control_w, u8 sign)
   */
 
 }
+
