@@ -1,8 +1,10 @@
-/////////////////////////////////////////////////////////////////////////
-// $Id: beos.cc,v 1.37 2010/02/26 14:18:18 sshwarts Exp $
-/////////////////////////////////////////////////////////////////////////
+//  Copyright (C) 2000  MandrakeSoft S.A.
 //
-//  Copyright (C) 2001-2009  The Bochs Project
+//    MandrakeSoft S.A.
+//    43, rue d'Aboukir
+//    75002 Paris - France
+//    http://www.linux-mandrake.com/
+//    http://www.mandrakesoft.com/
 //
 //  This library is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU Lesser General Public
@@ -16,24 +18,9 @@
 //
 //  You should have received a copy of the GNU Lesser General Public
 //  License along with this library; if not, write to the Free Software
-//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 
 
-// Define BX_PLUGGABLE in files that can be compiled into plugins.  For
-// platforms that require a special tag on exported symbols, BX_PLUGGABLE
-// is used to know when we are exporting symbols and when we are importing.
-#define BX_PLUGGABLE
-
-#include <stdlib.h>
-#include <stdio.h>
-#include <ctype.h>
-#include <string.h>
-
-#include "param_names.h"
-#include "bochs.h"
-#include "iodev.h"
-#if BX_WITH_BEOS
-
 #include <app/Application.h>
 #include <interface/Window.h>
 #include <interface/View.h>
@@ -41,41 +28,38 @@
 #include <interface/Bitmap.h>
 #include <interface/GraphicsDefs.h>
 
-//#include "icon_bochs.h"
+
+#include <stdlib.h>
+#include <stdio.h>
+#include <ctype.h>
+#include <string.h>
+
+#include "bochs.h"
+// #include "icon_bochs.h"
 #include "font/vga.bitmap.h"
 
-class bx_beos_gui_c : public bx_gui_c {
-public:
-  bx_beos_gui_c (void) {}
-  DECLARE_GUI_VIRTUAL_METHODS()
-};
+#define PAD_NEAREST(n, quantum) (( ((n) + ((quantum) - 1)) / (n) ) * (n))
 
-// declare one instance of the gui object and call macro to insert the
-// plugin code
-static bx_beos_gui_c *theGui = NULL;
-IMPLEMENT_GUI_PLUGIN_CODE(beos)
-
-#define LOG_THIS theGui->
-
-#define PAD_NEAREST(n, quantum) ((((n) + ((quantum) - 1)) / (n)) * (n))
 
 class BochsApplication : public BApplication {
+
 public:
   BochsApplication();
-};
+  };
 
 class BochsWindow : public BWindow {
+
 public:
   BochsWindow(BRect frame);
   virtual  bool  QuitRequested();
   virtual  void  FrameResized(float width, float height);
-};
+  };
 
 class BochsView : public BView {
 private:
-       BBitmap *backing_store;
-       BView *backing_view;
-
+	BBitmap *backing_store;
+	BView *backing_view;
+	
 public:
   BochsView(BRect frame, char *name);
   ~BochsView();
@@ -87,7 +71,7 @@ public:
   virtual  void  MouseUp(BPoint point);
   virtual  void  MouseMoved(BPoint point,
                             uint32 transit, const BMessage *message);
-  void DrawBitmap(const BBitmap *aBitmap, BPoint where);
+  void DrawBitmap(const BBitmap *aBitmap, BPoint where);							
   void FillRect(BRect r, pattern p = B_SOLID_HIGH);
   void SetHighColor(uchar r, uchar g, uchar b, uchar a = 255);
   void SetLowColor(uchar r, uchar g, uchar b, uchar a = 255);
@@ -95,7 +79,7 @@ public:
   void set_text_colors(void);
   void set_inv_text_colors(void);
   void set_headerbar_colors(void);
-};
+  };
 
 
 void GUI_end(void);
@@ -119,7 +103,8 @@ static BScreen *screen;
 static unsigned long rowsize_padded=0;
 static uint8 *rawdata = NULL;
 
-static unsigned int text_rows=25, text_cols=80;
+//static int rows=25, columns=80;
+
 static unsigned font_width, font_height;
 static Bit8u blank_line[80];
 static unsigned dimension_x, dimension_y;
@@ -127,13 +112,9 @@ static unsigned dimension_x, dimension_y;
 //static unsigned imDepth, imWide, imBPP;
 
 // current cursor coordinates
-//IRA=> Start
-static BPoint current;
-static BPoint previous;
-static Bit8u mouse_button_state = 0;
-//IRA=> End
 //static int prev_x=-1, prev_y=-1;
 //static int current_x=-1, current_y=-1;
+//static Bit8u mouse_button_state = 0;
 
 static unsigned prev_block_cursor_x=0;
 static unsigned prev_block_cursor_y=0;
@@ -157,7 +138,7 @@ Bit8u ascii_to_scancode[0x7f] = {
   0x23, 0x17, 0x24, 0x25, 0x26, 0x32, 0x31, 0x18, /* hijklmno */
   0x19, 0x10, 0x13, 0x1f, 0x14, 0x16, 0x2f, 0x11, /* pqrstuvw */
   0x2d, 0x15, 0x2c, 0x1a, 0x2b, 0x1b, 0x29        /* xyz{|}~  */
-};
+  };
 
 extern Bit8u graphics_snapshot[32 * 1024];
 //extern pc_keyb_c *pc_keyboard;
@@ -169,12 +150,12 @@ unsigned col_vals[256], curr_foreground, curr_background;
 
 static unsigned x_tilesize, y_tilesize;
 
-static struct {
+struct {
   BBitmap *bmap;
   unsigned xdim;
   unsigned ydim;
-} bx_bitmaps[BX_MAX_PIXMAPS];
-static unsigned bx_bitmap_entries = 0;
+  } bx_bitmaps[BX_MAX_PIXMAPS];
+unsigned bx_bitmap_entries = 0;
 
 static struct {
   BBitmap   *bitmap;
@@ -184,8 +165,7 @@ static struct {
   unsigned yorigin;
   unsigned alignment;
   void (*f)(void);
-} bx_headerbar_entry[BX_MAX_HEADERBAR_ENTRIES];
-
+  } bx_headerbar_entry[BX_MAX_HEADERBAR_ENTRIES];
 static unsigned bx_headerbar_y = 0;
 static unsigned bx_headerbar_entries = 0;
 static unsigned bx_bitmap_left_xorigin = 0;  // pixels from left
@@ -196,26 +176,42 @@ static unsigned char reverse_bitorder(unsigned char b);
 static void create_vga_font(void);
 static BBitmap *vgafont[256];
 
-void bx_beos_gui_c::specific_init(int argc, char **argv,
+static bx_gui_c *bx_gui_c_ptr;
+
+
+  void
+bx_gui_c::specific_init(bx_gui_c *th, int argc, char **argv,
                         unsigned tilewidth, unsigned tileheight,
                         unsigned header_bar_y)
 {
-  UNUSED(argc);
-  UNUSED(argv);
+  unsigned i;
+#if BX_CPU_LEVEL < 2
+  char *window_name = "Bochs 8086 emulator, http://world.std.com/~bochs";
+#elif BX_CPU_LEVEL == 2
+  char *window_name = "Bochs 80286 emulator, http://world.std.com/~bochs";
+#elif BX_CPU_LEVEL == 3
+  char *window_name = "Bochs 80386 emulator, http://world.std.com/~bochs";
+#else
+  char *window_name = "Bochs 80386+ emulator, http://world.std.com/~bochs";
+#endif
 
-  put("BGUI");
+  bx_gui_c_ptr = th;
+UNUSED(argc);
+UNUSED(argv);
+UNUSED(window_name);
 
-  if (SIM->get_param_bool(BXPN_PRIVATE_COLORMAP)->get()) {
-    BX_INFO(("BeOS: private_colormap option not handled yet."));
+if (bx_options.private_colormap) {
+  fprintf(stderr, "#WARNING: BeOS: private_colormap option not handled yet.\n");
   }
 
   x_tilesize = tilewidth;
   y_tilesize = tileheight;
   bx_headerbar_y = header_bar_y;
 
-  for (int i=0; i<80; i++) {
+  for (i=0; i<80; i++) {
     blank_line[i] = ' ';
-  }
+    }
+
 
   font_width = 8;
   font_height = 16;
@@ -223,8 +219,8 @@ void bx_beos_gui_c::specific_init(int argc, char **argv,
   // width = columns * font_width;
   // height = rows * font_height;
 
-BX_INFO(("font_width = %u", (unsigned) font_width));
-BX_INFO(("font_height = %u", (unsigned) font_height));
+bx_printf("font_width = %u\n", (unsigned) font_width);
+bx_printf("font_height = %u\n", (unsigned) font_height);
 
   // Create pixmap of depth 1 (bitmap) for icon
   // icon_pixmap = XCreateBitmapFromData(bx_x_display, win,
@@ -234,8 +230,8 @@ BX_INFO(("font_height = %u", (unsigned) font_height));
   // XSetBackground(bx_x_display, gc, col_vals[curr_background]);
   curr_foreground = 1;
   // XSetForeground(bx_x_display, gc, col_vals[curr_foreground]);
-  //XGrabPointer(bx_x_display, win, True, 0, GrabModeAsync, GrabModeAsync,
-  //  win, None, CurrentTime);
+  //XGrabPointer( bx_x_display, win, True, 0, GrabModeAsync, GrabModeAsync,
+  //  win, None, CurrentTime );
   //XFlush(bx_x_display);
 
   myApplication = new BochsApplication();
@@ -244,19 +240,19 @@ BX_INFO(("font_height = %u", (unsigned) font_height));
   while (1) {
     aWindow->Lock();
     if (aWindow->IsHidden()) {
-      aWindow->Unlock();
-      continue;
-    }
+     aWindow->Unlock();
+     continue;
+     }
     aWindow->Unlock();
     break;
-  }
+    }
 
   screen = new BScreen;
   // start out with all color map indeces pointing to Black
   cmap_index[0] = screen->IndexForColor(0, 0, 0);
   for (unsigned i=1; i<256; i++) {
     cmap_index[i] = cmap_index[0];
-  }
+    }
 
   rect.Set(0,0, x_tilesize-1, y_tilesize-1);
   image = new BBitmap(rect, B_COLOR_8_BIT);
@@ -266,55 +262,41 @@ BX_INFO(("font_height = %u", (unsigned) font_height));
   create_vga_font();
 }
 
-void bx_beos_gui_c::handle_events(void)
+
+
+  void
+bx_gui_c::handle_events(void)
 {
   Bit32u key;
 
-  while (head != tail) {
+  while ( head != tail ) {
     key = deq_key_event();
-    DEV_kbd_gen_scancode(key);
-  }
-//IRA=> Start
-  if (aView) {
-      unsigned long buttons;
-      aView->LockLooper();
-      aView->GetMouse(&current, &buttons, false);
-      aView->UnlockLooper();
-
-      Bit8u newstate = 0; //please note: 2nd and 3rd button are mapped the same
-      if (buttons & B_PRIMARY_MOUSE_BUTTON)
-        newstate |= 0x01;
-      if (buttons & B_SECONDARY_MOUSE_BUTTON)
-        newstate |= 0x02;
-      if (buttons & B_TERTIARY_MOUSE_BUTTON)
-        newstate |= 0x02;
-
-      if (current != previous || mouse_button_state != newstate) {
-        int dx = (int)(current.x - previous.x) *2;
-        int dy = -(int)((current.y - previous.y) *2);
-        DEV_mouse_motion(dx, dy, newstate);
-        mouse_button_state = newstate;
-        previous = current;
-      }
-  }
-//IRA=> End
+    bx_devices.keyboard->gen_scancode(key);
+    }
 }
 
-void bx_beos_gui_c::flush(void)
+  void
+bx_gui_c::flush(void)
 {
-  if (view_attached) aView->Flush();
+  if (view_attached)
+    aView->Flush();
 }
 
-void bx_beos_gui_c::clear_screen(void)
+
+  void
+bx_gui_c::clear_screen(void)
 {
   aWindow->Lock();
   aView->FillRect(BRect(0, bx_headerbar_y, dimension_x-1, dimension_y-1), B_SOLID_LOW);
   aWindow->Unlock();
 }
 
-void bx_beos_gui_c::text_update(Bit8u *old_text, Bit8u *new_text,
+
+
+  void
+bx_gui_c::text_update(Bit8u *old_text, Bit8u *new_text,
                       unsigned long cursor_x, unsigned long cursor_y,
-                      bx_vga_tminfo_t tm_info)
+                      unsigned nrows)
 {
   unsigned i, x, y;
   BPoint point;
@@ -324,90 +306,74 @@ void bx_beos_gui_c::text_update(Bit8u *old_text, Bit8u *new_text,
   aWindow->Lock();
 
   // Number of characters on screen, variable number of rows
-  nchars = text_cols * text_rows;
+  nchars = 80*nrows;
 
   // first draw over character at original block cursor location
-  if ((prev_block_cursor_y*text_cols + prev_block_cursor_x) < nchars) {
-    achar = new_text[(prev_block_cursor_y*text_cols + prev_block_cursor_x)*2];
+  if ( (prev_block_cursor_y*80 + prev_block_cursor_x) < nchars ) {
+    achar = new_text[(prev_block_cursor_y*80 + prev_block_cursor_x)*2];
     point.Set(prev_block_cursor_x*8, prev_block_cursor_y*16 + bx_headerbar_y);
-    aView->DrawBitmap(vgafont[achar], point);
-  }
+    aView->DrawBitmap(vgafont[achar], point );
+    }
 
   for (i=0; i<nchars*2; i+=2) {
-    if ((old_text[i]!=new_text[i]) ||
-        (old_text[i+1]!=new_text[i+1]))
-    {
+    if ( (old_text[i]!=new_text[i]) ||
+         (old_text[i+1]!=new_text[i+1]) ) {
+
       achar = new_text[i];
 
-      x = (i/2) % text_cols;
-      y = (i/2) / text_cols;
+      x = (i/2) % 80;
+      y = (i/2) / 80;
 
       point.Set(x*8, y*16 + bx_headerbar_y);
-      aView->DrawBitmap(vgafont[achar], point);
+      aView->DrawBitmap(vgafont[achar], point );
+      }
     }
-  }
 
   prev_block_cursor_x = cursor_x;
   prev_block_cursor_y = cursor_y;
 
   // now draw character at new block cursor location in reverse
-  if ((cursor_y*text_cols + cursor_x) < nchars) {
-    achar = new_text[(cursor_y*text_cols + cursor_x)*2];
+  if ( (cursor_y*80 + cursor_x) < nchars ) {
+    achar = new_text[(cursor_y*80 + cursor_x)*2];
     point.Set(cursor_x*8, cursor_y*16 + bx_headerbar_y);
     aView->set_inv_text_colors();
-    aView->DrawBitmap(vgafont[achar], point);
+    aView->DrawBitmap(vgafont[achar], point );
     aView->set_text_colors();
-  }
+    }
 
   aWindow->Unlock();
 }
 
-int bx_beos_gui_c::get_clipboard_text(Bit8u **bytes, Bit32s *nbytes)
-{
-  return 0;
-}
 
-int bx_beos_gui_c::set_clipboard_text(char *text_snapshot, Bit32u len)
-{
-  return 0;
-}
-
-void bx_beos_gui_c::graphics_tile_update(Bit8u *tile, unsigned x0, unsigned y0)
+  void
+bx_gui_c::graphics_tile_update(Bit8u *tile, unsigned x0, unsigned y0)
 {
   for (unsigned y=0; y<y_tilesize; y++) {
     for (unsigned x=0; x<x_tilesize; x++) {
       rawdata[y*rowsize_padded + x] = cmap_index[ tile[y*x_tilesize + x] ];
+      }
     }
-  }
   aWindow->Lock();
   image->SetBits(rawdata, rowsize_padded * y_tilesize, 0, B_COLOR_8_BIT);
   image_origin.Set(x0, y0 + bx_headerbar_y);
 
-  aView->DrawBitmap(image, image_origin);
+  aView->DrawBitmap( image, image_origin );
   aWindow->Unlock();
 }
 
-bx_bool bx_beos_gui_c::palette_change(unsigned index, unsigned red, unsigned green, unsigned blue)
+
+  Boolean
+bx_gui_c::palette_change(unsigned index, unsigned red, unsigned green, unsigned blue)
 {
-  cmap_index[index] = screen->IndexForColor(red, green, blue);
+  cmap_index[index] = screen->IndexForColor(
+    red, green, blue);
   return(1);
 }
 
-void bx_beos_gui_c::dimension_update(unsigned x, unsigned y, unsigned fheight, unsigned fwidth, unsigned bpp)
+
+  void
+bx_gui_c::dimension_update(unsigned x, unsigned y)
 {
-  if (bpp > 8) {
-    BX_PANIC(("%d bpp graphics mode not supported yet", bpp));
-  }
-  if (fheight > 0) {
-    text_cols = x / fwidth;
-    text_rows = y / fheight;
-    if (fwidth != 8) {
-      x = x * 8 / fwidth;
-    }
-    if (fheight != 16) {
-      y = y * 16 / fheight;
-    }
-  }
   aWindow->Lock();
   aWindow->ResizeTo(x, y + bx_headerbar_y);
   aWindow->Unlock();
@@ -416,9 +382,12 @@ void bx_beos_gui_c::dimension_update(unsigned x, unsigned y, unsigned fheight, u
 
 //////////////////////////////////////////////////////
 
-void GUI_end()
+
+  void
+GUI_end()
 {
   //myApplication->Run();
+
   delete(myApplication);
 }
 
@@ -454,10 +423,11 @@ BochsApplication::BochsApplication()
   aWindow->Show();
 }
 
+
 //void set_palette_entry(long i,rgb_color c);
 
 BochsWindow::BochsWindow(BRect frame)
-        : BWindow(frame, "BeBochs V1.3.pre compiled Bernd Korz", B_TITLED_WINDOW, B_NOT_RESIZABLE)
+        : BWindow(frame, "Bochs", B_TITLED_WINDOW, B_NOT_RESIZABLE)
 {
 }
 
@@ -467,36 +437,44 @@ bool BochsWindow::QuitRequested()
   return(TRUE);
 }
 
-void BochsWindow::FrameResized(float width, float height)
+
+  void
+BochsWindow::FrameResized(float width, float height)
 {
   dimension_x = unsigned(width);
   dimension_y = unsigned(height) + bx_headerbar_y;
-  theGui->show_headerbar();
+  if ( bx_gui_c_ptr )
+    bx_gui_c_ptr->show_headerbar();
 }
 
+
 //------------------------------
 
+
 BochsView::BochsView(BRect rect, char *name)
           : BView(rect, name, B_FOLLOW_ALL, B_WILL_DRAW)
 {
-       backing_store = new BBitmap(rect, B_BITMAP_ACCEPTS_VIEWS, B_COLOR_8_BIT);
-       backing_view = new BView(rect,"backing store", B_FOLLOW_ALL, B_WILL_DRAW);
-       backing_store->AddChild(backing_view);
+	backing_store = new BBitmap(rect, B_BITMAP_ACCEPTS_VIEWS, B_COLOR_8_BIT);
+	backing_view = new BView(rect,"backing store", B_FOLLOW_ALL, B_WILL_DRAW);
+	backing_store->AddChild(backing_view);
 }
 
-void BochsView::set_text_colors(void)
+  void
+BochsView::set_text_colors(void)
 {
   aView->SetHighColor(255, 255, 255);
   aView->SetLowColor(0, 0, 0);
 }
 
-void BochsView::set_inv_text_colors(void)
+  void
+BochsView::set_inv_text_colors(void)
 {
   aView->SetHighColor(0, 0, 0);
   aView->SetLowColor(255, 255, 255);
 }
 
-void BochsView::set_headerbar_colors(void)
+  void
+BochsView::set_headerbar_colors(void)
 {
   aView->SetHighColor(0, 0, 0);
   aView->SetLowColor(255, 255, 255);
@@ -517,31 +495,30 @@ void BochsView::AttachedToWindow()
   view_attached = 1;
 }
 
-void BochsView::MouseDown(BPoint point)
+void  BochsView::MouseDown(BPoint point)
 {
   UNUSED(point);
   if (point.y < BX_HEADER_BAR_Y) {
     headerbar_click(int(point.x), int(point.y));
     return;
-  }
-  BX_DEBUG(("mousedown()"));
+    }
+  fprintf(stderr, "# mousedown()\n");
 }
 
-void BochsView::MouseUp(BPoint point)
+void  BochsView::MouseUp(BPoint point)
 {
   UNUSED(point);
   // currently a place holder function
-  BX_DEBUG(("mouseup()"));
-  BView::MouseUp(point);
+  fprintf(stderr, "# mouseup()\n");
 }
 
-void BochsView::MouseMoved(BPoint point,
+void  BochsView::MouseMoved(BPoint point,
                           uint32 transit, const BMessage *message)
 {
   UNUSED(point);
   UNUSED(transit);
   UNUSED(message);
-  BX_DEBUG(("mousemoved()"));
+  fprintf(stderr, "# mousemoved()\n");
 }
 
 void BochsView::KeyDown(const char *bytes, int32 numBytes)
@@ -553,10 +530,10 @@ void BochsView::KeyDown(const char *bytes, int32 numBytes)
   uint8 byte;
 
   msg = Window()->CurrentMessage();
-  if (!msg) {
-    BX_DEBUG(("keydown() msg NULL"));
+  if ( !msg ) {
+    fprintf(stderr, "# keydown() msg NULL\n");
     return;
-  }
+    }
   modifiers = msg->FindInt32("modifiers");
 #if 0
   B_SHIFT_KEY          = 0x00000001,
@@ -578,20 +555,20 @@ void BochsView::KeyDown(const char *bytes, int32 numBytes)
 #endif
 //if (modifiers) {
 //  fprintf(stderr, "# modifiers = %08x\n", (unsigned) modifiers);
-//}
+//  }
 
   if (numBytes == 1) {
     //fprintf(stderr, "# down: char %02xh\n", (unsigned) bytes[0]);
     byte = bytes[0];
-    if (byte == 0x00) {
+    if ( byte == 0x00 ) {
       // Ctrl-Space
       enq_key_event(BX_KEY_CTRL_L,  BX_KEY_PRESSED);
       enq_key_event(BX_KEY_SPACE, BX_KEY_PRESSED);
       enq_key_event(BX_KEY_SPACE, BX_KEY_RELEASED);
       enq_key_event(BX_KEY_CTRL_L,  BX_KEY_RELEASED);
       return;
-    }
-    if (byte == 0x1b) {
+      }
+    if ( byte == 0x1b ) {
       // Esc
       if (modifiers & B_CONTROL_KEY)
         enq_key_event(BX_KEY_CTRL_L,  BX_KEY_PRESSED);
@@ -600,15 +577,15 @@ void BochsView::KeyDown(const char *bytes, int32 numBytes)
       if (modifiers & B_CONTROL_KEY)
         enq_key_event(BX_KEY_CTRL_L,  BX_KEY_RELEASED);
       return;
-    }
-    if ((byte >= 0x30) && (byte <= 0x39)) {
+      }
+    if ( (byte >= 0x30) && (byte <= 0x39) ) {
       // 0 .. 9
       byte -= 0x30;
       enq_key_event(BX_KEY_0 + byte, BX_KEY_PRESSED);
       enq_key_event(BX_KEY_0 + byte, BX_KEY_RELEASED);
       return;
-    }
-    if ((byte >= 0x41) && (byte <= 0x5A)) {
+      }
+    if ( (byte >= 0x41) && (byte <= 0x5A) ) {
       // A .. Z
       byte -= 0x41;
       enq_key_event(BX_KEY_SHIFT_L,    BX_KEY_PRESSED);
@@ -616,14 +593,14 @@ void BochsView::KeyDown(const char *bytes, int32 numBytes)
       enq_key_event(BX_KEY_A + byte, BX_KEY_RELEASED);
       enq_key_event(BX_KEY_SHIFT_L,    BX_KEY_RELEASED);
       return;
-    }
-    if ((byte >= 0x61) && (byte <= 0x7A)) {
+      }
+    if ( (byte >= 0x61) && (byte <= 0x7A) ) {
       // a .. z
       byte -= 0x61;
       enq_key_event(BX_KEY_A + byte, BX_KEY_PRESSED);
       enq_key_event(BX_KEY_A + byte, BX_KEY_RELEASED);
       return;
-    }
+      }
     switch (byte) {
       case 0x20: // Space
         enq_key_event(BX_KEY_SPACE, BX_KEY_PRESSED);
@@ -834,7 +811,7 @@ void BochsView::KeyDown(const char *bytes, int32 numBytes)
 #if 0
       case B_FUNCTION_KEY: break;
         msg->FindInt32("key", &key);
-        switch (key) {
+        switch ( key ) {
           case B_F1_KEY: break;
           case B_F2_KEY: break;
           case B_F3_KEY: break;
@@ -853,7 +830,7 @@ void BochsView::KeyDown(const char *bytes, int32 numBytes)
           default:
             fprintf(stderr, "# keydown() unknown function key %08xh\n",
               (unsigned) key);
-        }
+          }
 #endif
       case B_INSERT: break;
         enq_key_event(BX_KEY_INSERT, BX_KEY_PRESSED);
@@ -881,7 +858,7 @@ void BochsView::KeyDown(const char *bytes, int32 numBytes)
         break;
 
       default:
-        if ((byte >= 0x01) && (byte <= 0x1a)) {
+        if ( (byte >= 0x01) && (byte <= 0x1a) ) {
           // If the above keys dont catch this case, synthesize a
           // Ctrl-A .. Ctrl-Z event
           byte -= 1;
@@ -890,17 +867,17 @@ void BochsView::KeyDown(const char *bytes, int32 numBytes)
           enq_key_event(BX_KEY_A + byte, BX_KEY_RELEASED);
           enq_key_event(BX_KEY_CTRL_L,     BX_KEY_RELEASED);
           return;
-        }
+          }
         fprintf(stderr, "# keydown: char %02xh unhandled\n",
           (unsigned) bytes[0]);
         return;
-    }
+      }
     return;
-  }
+    }
   else {
     // ignore for now
     fprintf(stderr, "# keydown() ignoring multibyte key\n");
-  }
+    }
 }
 
 void BochsView::KeyUp(const char *bytes, int32 numBytes)
@@ -911,88 +888,99 @@ void BochsView::KeyUp(const char *bytes, int32 numBytes)
 
 void BochsView::Draw(BRect rect)
 {
-  DrawBitmapAsync(backing_store, rect, rect);
+	DrawBitmapAsync(backing_store, rect, rect);
 }
 
 BochsView::~BochsView()
 {
-  delete backing_store;
-  delete backing_view;
+	delete backing_store;
+	delete backing_view;
 }
 
-void BochsView::SetFont(const BFont *font, uint32 mask)
+void 
+BochsView::SetFont(const BFont *font, uint32 mask)
 {
-  backing_store->Lock();
-  backing_view->SetFont(font,mask);
-  backing_store->Unlock();
+	backing_store->Lock();
+	backing_view->SetFont(font,mask);
+	backing_store->Unlock();
 }
 
-void BochsView::SetHighColor(uchar r, uchar g, uchar b, uchar a)
+void 
+BochsView::SetHighColor(uchar r, uchar g, uchar b, uchar a)
 {
-  backing_store->Lock();
-  backing_view->SetHighColor(r,g,b,a);
-  backing_store->Unlock();
+	backing_store->Lock();
+	backing_view->SetHighColor(r,g,b,a);
+	backing_store->Unlock();
 }
 
-void BochsView::SetLowColor(uchar r, uchar g, uchar b, uchar a)
+void 
+BochsView::SetLowColor(uchar r, uchar g, uchar b, uchar a)
 {
-  backing_store->Lock();
-  backing_view->SetLowColor(r,g,b,a);
-  backing_store->Unlock();
+	backing_store->Lock();
+	backing_view->SetLowColor(r,g,b,a);
+	backing_store->Unlock();
 }
 
-void BochsView::DrawBitmap(const BBitmap *aBitmap, BPoint where)
+void 
+BochsView::DrawBitmap(const BBitmap *aBitmap, BPoint where)
 {
-  backing_store->Lock();
-  backing_view->DrawBitmap(aBitmap,where);
-  backing_store->Unlock();
-  BRect r = aBitmap->Bounds();
-  r.OffsetBy(where);
-  Invalidate(r);
+	backing_store->Lock();
+	backing_view->DrawBitmap(aBitmap,where);
+	backing_store->Unlock();
+	BRect r = aBitmap->Bounds();
+	r.OffsetBy(where);
+	Invalidate(r);
 }
 
-void BochsView::FillRect(BRect r, pattern p)
+void 
+BochsView::FillRect(BRect r, pattern p)
 {
-  backing_store->Lock();
-  backing_view->FillRect(r,p);
-  backing_store->Unlock();
-  Invalidate(r);
+	backing_store->Lock();
+	backing_view->FillRect(r,p);
+	backing_store->Unlock();
+	Invalidate(r);
 }
 
-void enq_key_event(Bit32u key, Bit32u press_release)
+
+
+  void
+enq_key_event(Bit32u key, Bit32u press_release)
 {
-  if (((tail+1) % SCANCODE_BUFSIZE) == head) {
+  if ( ((tail+1) % SCANCODE_BUFSIZE) == head ) {
     fprintf(stderr, "# enq_key_event: buffer full\n");
     return;
-  }
+    }
   keyevents[tail] = key | press_release;
   tail = (tail + 1) % SCANCODE_BUFSIZE;
 }
 
-Bit32u deq_key_event(void)
+  Bit32u
+deq_key_event(void)
 {
   Bit32u key;
 
-  if (head == tail) {
+  if ( head == tail ) {
     fprintf(stderr, "# deq_key_event: buffer empty\n");
     return(0);
-  }
+    }
   key = keyevents[head];
   head = (head + 1) % SCANCODE_BUFSIZE;
   return(key);
 }
 
-unsigned char reverse_bitorder(unsigned char b)
+  unsigned char
+reverse_bitorder(unsigned char b)
 {
   unsigned char ret=0;
   for (unsigned i=0; i<8; i++) {
     ret |= (b & 0x01) << (7-i);
     b >>= 1;
-  }
+    }
   return(ret);
 }
 
-unsigned bx_beos_gui_c::create_bitmap(const unsigned char *bmap,
+  unsigned
+bx_gui_c::create_bitmap(const unsigned char *bmap,
                         unsigned xdim, unsigned ydim)
 {
   BRect rect(0.0, 0.0, xdim-1, ydim-1);
@@ -1001,8 +989,8 @@ unsigned bx_beos_gui_c::create_bitmap(const unsigned char *bmap,
   unsigned char *data;
 
   if (bx_bitmap_entries >= BX_MAX_PIXMAPS) {
-    BX_PANIC(("beos: too many pixmaps, increase BX_MAX_PIXMAPS"));
-  }
+    bx_panic("beos: too many pixmaps, increase BX_MAX_PIXMAPS\n");
+    }
 
   bx_bitmaps[bx_bitmap_entries].bmap =
     new BBitmap(rect, B_MONOCHROME_1_BIT);
@@ -1012,24 +1000,25 @@ unsigned bx_beos_gui_c::create_bitmap(const unsigned char *bmap,
   data = (unsigned char *) bx_bitmaps[bx_bitmap_entries].bmap->Bits();
   for (int32 i=0; i<bitslength; i++) {
     data[i] = reverse_bitorder(bmap[i]);
-  }
+    }
 
   bx_bitmaps[bx_bitmap_entries].xdim = xdim;
   bx_bitmaps[bx_bitmap_entries].ydim = ydim;
   if (!bx_bitmaps[bx_bitmap_entries].bmap) {
-    BX_PANIC(("beos: could not create bitmap"));
-  }
+    bx_panic("beos: could not create bitmap\n");
+    }
   bx_bitmap_entries++;
   return(bx_bitmap_entries-1); // return index as handle
 }
 
-unsigned bx_beos_gui_c::headerbar_bitmap(unsigned bmap_id, unsigned alignment,
+  unsigned
+bx_gui_c::headerbar_bitmap(unsigned bmap_id, unsigned alignment,
                            void (*f)(void))
 {
   unsigned hb_index;
 
-  if ((bx_headerbar_entries+1) > BX_MAX_HEADERBAR_ENTRIES)
-    BX_PANIC(("beos: too many headerbar entries, increase BX_MAX_HEADERBAR_ENTRIES"));
+  if ( (bx_headerbar_entries+1) > BX_MAX_HEADERBAR_ENTRIES )
+    bx_panic("beos: too many headerbar entries, increase BX_MAX_HEADERBAR_ENTRIES\n");
 
   bx_headerbar_entries++;
   hb_index = bx_headerbar_entries - 1;
@@ -1043,16 +1032,17 @@ unsigned bx_beos_gui_c::headerbar_bitmap(unsigned bmap_id, unsigned alignment,
     bx_headerbar_entry[hb_index].xorigin = bx_bitmap_left_xorigin;
     bx_headerbar_entry[hb_index].yorigin = 0;
     bx_bitmap_left_xorigin += bx_bitmaps[bmap_id].xdim;
-  }
+    }
   else { // BX_GRAVITY_RIGHT
     bx_bitmap_right_xorigin += bx_bitmaps[bmap_id].xdim;
     bx_headerbar_entry[hb_index].xorigin = bx_bitmap_right_xorigin;
     bx_headerbar_entry[hb_index].yorigin = 0;
-  }
+    }
   return(hb_index);
 }
 
-void bx_beos_gui_c::replace_bitmap(unsigned hbar_id, unsigned bmap_id)
+  void
+bx_gui_c::replace_bitmap(unsigned hbar_id, unsigned bmap_id)
 {
   unsigned xorigin;
 
@@ -1069,7 +1059,8 @@ void bx_beos_gui_c::replace_bitmap(unsigned hbar_id, unsigned bmap_id)
   aWindow->Unlock();
 }
 
-void bx_beos_gui_c::show_headerbar(void)
+  void
+bx_gui_c::show_headerbar(void)
 {
   unsigned xorigin;
   BPoint origin;
@@ -1085,13 +1076,15 @@ void bx_beos_gui_c::show_headerbar(void)
     else
       xorigin = dimension_x - bx_headerbar_entry[i].xorigin;
     origin.Set(xorigin, 0);
-    aView->DrawBitmap(bx_headerbar_entry[i].bitmap, origin);
-  }
+    aView->DrawBitmap( bx_headerbar_entry[i].bitmap, origin );
+    }
   aView->set_text_colors();
   aWindow->Unlock();
 }
 
-void headerbar_click(int x, int y)
+
+  void
+headerbar_click(int x, int y)
 {
   int xorigin;
 
@@ -1102,28 +1095,30 @@ void headerbar_click(int x, int y)
       xorigin = bx_headerbar_entry[i].xorigin;
     else
       xorigin = dimension_x - bx_headerbar_entry[i].xorigin;
-    if ((x>=xorigin) && (x<(xorigin+int(bx_headerbar_entry[i].xdim)))) {
+    if ( (x>=xorigin) && (x<(xorigin+int(bx_headerbar_entry[i].xdim))) ) {
       bx_headerbar_entry[i].f();
       return;
+      }
     }
-  }
 }
 
-void create_vga_font(void)
+
+  void
+create_vga_font(void)
 {
   int32 bitslength;
   int32 bytesperrow;
   unsigned char *data;
   BRect brect(0,0, 7,15);
 
-  BX_INFO(("BeOS: creating VGA font from bitmaps"));
+  fprintf(stderr, "# BeOS: creating VGA font from bitmaps\n");
 
   // VGA font is 8wide x 16high
   for (unsigned c=0; c<256; c++) {
     vgafont[c] = new BBitmap(brect, B_MONOCHROME_1_BIT);
     if (!vgafont[c]) {
-      BX_PANIC(("beos: could not create bitmap"));
-    }
+      bx_panic("beos: could not create bitmap\n");
+      }
 
     bitslength = vgafont[c]->BitsLength();
     bytesperrow = vgafont[c]->BytesPerRow();
@@ -1131,37 +1126,13 @@ void create_vga_font(void)
     memset(data, 0, bitslength);
     for (unsigned i=0; i<16; i++) {
       data[i*bytesperrow] = reverse_bitorder(bx_vgafont[c].data[i]);
+      }
     }
-  }
 }
 
-void bx_beos_gui_c::exit(void)
+
+  void
+bx_gui_c::exit(void)
 {
-  fprintf(stderr, "# WARNING: BEOS: bx_beos_gui_c::exit() not implemented yet.\n");
+  fprintf(stderr, "# WARNING: BEOS: bx_gui_c::exit() not implemented yet.\n");
 }
-
-//IRA=> Start
-// This is called whenever the mouse_enabled parameter changes.  It
-// can change because of a gui event such as clicking on the mouse-enable
-// bitmap or pressing the middle button, or from the configuration interface.
-// In all those cases, setting the parameter value will get you here.
-
-void bx_beos_gui_c::mouse_enabled_changed_specific (bx_bool val)
-{
-  BX_DEBUG (("mouse_enabled=%d, BeOS specific code", val?1:0));
-  if (val) {
-    BX_INFO(("[x] Mouse on"));
-//    mouse_enable_x = current_x;
-//    mouse_enable_y = current_y;
-    be_app->HideCursor();
-    // Move the cursor to a 'safe' place
-//    warp_cursor(warp_home_x-current_x, warp_home_y-current_y);
-  } else {
-    BX_INFO(("[x] Mouse off"));
-    be_app->ShowCursor();
-//    warp_cursor(mouse_enable_x-current_x, mouse_enable_y-current_y);
-  }
-}
-//IRA=> End
-
-#endif /* if BX_WITH_BEOS */
