@@ -1,8 +1,10 @@
-/////////////////////////////////////////////////////////////////////////
-// $Id: nogui.cc 12081 2013-12-29 12:56:52Z vruppert $
-/////////////////////////////////////////////////////////////////////////
+//  Copyright (C) 2000  MandrakeSoft S.A.
 //
-//  Copyright (C) 2001-2013  The Bochs Project
+//    MandrakeSoft S.A.
+//    43, rue d'Aboukir
+//    75002 Paris - France
+//    http://www.linux-mandrake.com/
+//    http://www.mandrakesoft.com/
 //
 //  This library is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU Lesser General Public
@@ -16,40 +18,20 @@
 //
 //  You should have received a copy of the GNU Lesser General Public
 //  License along with this library; if not, write to the Free Software
-//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 
 
-// Define BX_PLUGGABLE in files that can be compiled into plugins.  For
-// platforms that require a special tag on exported symbols, BX_PLUGGABLE
-// is used to know when we are exporting symbols and when we are importing.
-#define BX_PLUGGABLE
 
 #include "bochs.h"
-#include "plugin.h"
-#include "param_names.h"
-
-#if BX_WITH_NOGUI
 #include "icon_bochs.h"
 
-class bx_nogui_gui_c : public bx_gui_c {
-public:
-  bx_nogui_gui_c (void) {}
-  DECLARE_GUI_VIRTUAL_METHODS()
-};
-
-// declare one instance of the gui object and call macro to insert the
-// plugin code
-static bx_nogui_gui_c *theGui = NULL;
-IMPLEMENT_GUI_PLUGIN_CODE(nogui)
-
-#define LOG_THIS theGui->
 
 // This file defines stubs for the GUI interface, which is a
 // place to start if you want to port bochs to a platform, for
 // which there is no support for your native GUI, or if you want to compile
 // bochs without any native GUI support (no output window or
 // keyboard input will be possible).
-// Look in 'x.cc', 'carbon.cc', and 'win32.cc' for specific
+// Look in 'x.cc', 'beos.cc', and 'win32.cc' for specific
 // implementations of this interface.  -Kevin
 
 
@@ -57,28 +39,37 @@ IMPLEMENT_GUI_PLUGIN_CODE(nogui)
 // ::SPECIFIC_INIT()
 //
 // Called from gui.cc, once upon program startup, to allow for the
-// specific GUI code (X11, Win32, ...) to be initialized.
+// specific GUI code (X11, BeOS, ...) to be initialized.
 //
-// argc, argv: these arguments can be used to initialize the GUI with
-//     specific options (X11 options, Win32 options,...)
+// th: a 'this' pointer to the gui class.  If a function external to the
+//     class needs access, store this pointer and use later.
+// argc, argv: not used right now, but the intention is to pass native GUI
+//     specific options from the command line.  (X11 options, BeOS options,...)
 //
+// tilewidth, tileheight: for optimization, graphics_tile_update() passes
+//     only updated regions of the screen to the gui code to be redrawn.
+//     These define the dimensions of a region (tile).
 // headerbar_y:  A headerbar (toolbar) is display on the top of the
 //     VGA window, showing floppy status, and other information.  It
 //     always assumes the width of the current VGA mode width, but
 //     it's height is defined by this parameter.
 
-void bx_nogui_gui_c::specific_init(int argc, char **argv, unsigned headerbar_y)
+  void
+bx_gui_c::specific_init(bx_gui_c *th, int argc, char **argv, unsigned tilewidth, unsigned tileheight,
+                     unsigned headerbar_y)
 {
-  put("NOGUI");
+  UNUSED(th);
   UNUSED(argc);
   UNUSED(argv);
+  UNUSED(tilewidth);
+  UNUSED(tileheight);
   UNUSED(headerbar_y);
 
   UNUSED(bochs_icon_bits);  // global variable
 
-  if (SIM->get_param_bool(BXPN_PRIVATE_COLORMAP)->get()) {
-    BX_INFO(("private_colormap option ignored."));
-  }
+  if (bx_options.private_colormap) {
+    fprintf(stderr, "# WARNING: NOGUI: private_colormap option ignored.\n");
+    }
 }
 
 
@@ -88,7 +79,8 @@ void bx_nogui_gui_c::specific_init(int argc, char **argv, unsigned headerbar_y)
 // the gui code can poll for keyboard, mouse, and other
 // relevant events.
 
-void bx_nogui_gui_c::handle_events(void)
+  void
+bx_gui_c::handle_events(void)
 {
 }
 
@@ -98,7 +90,8 @@ void bx_nogui_gui_c::handle_events(void)
 // Called periodically, requesting that the gui code flush all pending
 // screen update requests.
 
-void bx_nogui_gui_c::flush(void)
+  void
+bx_gui_c::flush(void)
 {
 }
 
@@ -108,7 +101,8 @@ void bx_nogui_gui_c::flush(void)
 // Called to request that the VGA region is cleared.  Don't
 // clear the area that defines the headerbar.
 
-void bx_nogui_gui_c::clear_screen(void)
+  void
+bx_gui_c::clear_screen(void)
 {
 }
 
@@ -124,49 +118,25 @@ void bx_nogui_gui_c::clear_screen(void)
 // new_text: array of character/attributes making up the current
 //           contents, which should now be displayed.  See below
 //
-// format of old_text & new_text: each is tm_info->line_offset*text_rows
-//     bytes long. Each character consists of 2 bytes.  The first by is
-//     the character value, the second is the attribute byte.
+// format of old_text & new_text: each is 4000 bytes long.
+//     This represents 80 characters wide by 25 high, with
+//     each character being 2 bytes.  The first by is the
+//     character value, the second is the attribute byte.
+//     I currently don't handle the attribute byte.
 //
 // cursor_x: new x location of cursor
 // cursor_y: new y location of cursor
-// tm_info:  this structure contains information for additional
-//           features in text mode (cursor shape, line offset,...)
 
-void bx_nogui_gui_c::text_update(Bit8u *old_text, Bit8u *new_text,
-                      unsigned long cursor_x, unsigned long cursor_y,
-                      bx_vga_tminfo_t *tm_info)
+  void
+bx_gui_c::text_update(Bit8u *old_text, Bit8u *new_text,
+                      unsigned long cursor_x, unsigned long cursor_y
+                      unsigned nrows)
 {
   UNUSED(old_text);
   UNUSED(new_text);
   UNUSED(cursor_x);
   UNUSED(cursor_y);
-  UNUSED(tm_info);
-}
-
-
-// ::GET_CLIPBOARD_TEXT()
-//
-// Called to get text from the GUI clipboard. Returns 1 if successful.
-
-int bx_nogui_gui_c::get_clipboard_text(Bit8u **bytes, Bit32s *nbytes)
-{
-  UNUSED(bytes);
-  UNUSED(nbytes);
-  return 0;
-}
-
-
-// ::SET_CLIPBOARD_TEXT()
-//
-// Called to copy the text screen contents to the GUI clipboard.
-// Returns 1 if successful.
-
-int bx_nogui_gui_c::set_clipboard_text(char *text_snapshot, Bit32u len)
-{
-  UNUSED(text_snapshot);
-  UNUSED(len);
-  return 0;
+  UNUSED(nrows);
 }
 
 
@@ -177,7 +147,8 @@ int bx_nogui_gui_c::set_clipboard_text(char *text_snapshot, Bit32u len)
 // returns: 0=no screen update needed (color map change has direct effect)
 //          1=screen updated needed (redraw using current colormap)
 
-bx_bool bx_nogui_gui_c::palette_change(Bit8u index, Bit8u red, Bit8u green, Bit8u blue)
+  Boolean
+bx_gui_c::palette_change(unsigned index, unsigned red, unsigned green, unsigned blue)
 {
   UNUSED(index);
   UNUSED(red);
@@ -193,8 +164,8 @@ bx_bool bx_nogui_gui_c::palette_change(Bit8u index, Bit8u red, Bit8u green, Bit8
 // screen, since info in this region has changed.
 //
 // tile: array of 8bit values representing a block of pixels with
-//       dimension equal to the 'x_tilesize' & 'y_tilesize' members.
-//       Each value specifies an index into the
+//       dimension equal to the 'tilewidth' & 'tileheight' parameters to
+//       ::specific_init().  Each value specifies an index into the
 //       array of colors you allocated for ::palette_change()
 // x0: x origin of tile
 // y0: y origin of tile
@@ -202,7 +173,8 @@ bx_bool bx_nogui_gui_c::palette_change(Bit8u index, Bit8u red, Bit8u green, Bit8
 // note: origin of tile and of window based on (0,0) being in the upper
 //       left of the window.
 
-void bx_nogui_gui_c::graphics_tile_update(Bit8u *tile, unsigned x0, unsigned y0)
+  void
+bx_gui_c::graphics_tile_update(Bit8u *tile, unsigned x0, unsigned y0)
 {
   UNUSED(tile);
   UNUSED(x0);
@@ -210,6 +182,7 @@ void bx_nogui_gui_c::graphics_tile_update(Bit8u *tile, unsigned x0, unsigned y0)
 }
 
 
+
 // ::DIMENSION_UPDATE()
 //
 // Called when the VGA mode changes it's X,Y dimensions.
@@ -218,17 +191,12 @@ void bx_nogui_gui_c::graphics_tile_update(Bit8u *tile, unsigned x0, unsigned y0)
 //
 // x: new VGA x size
 // y: new VGA y size (add headerbar_y parameter from ::specific_init().
-// fheight: new VGA character height in text mode
-// fwidth : new VGA character width in text mode
-// bpp : bits per pixel in graphics mode
 
-void bx_nogui_gui_c::dimension_update(unsigned x, unsigned y, unsigned fheight, unsigned fwidth, unsigned bpp)
+  void
+bx_gui_c::dimension_update(unsigned x, unsigned y)
 {
-  guest_textmode = (fheight > 0);
-  guest_xres = x;
-  guest_yres = y;
-  guest_bpp = bpp;
-  UNUSED(fwidth);
+  UNUSED(x);
+  UNUSED(y);
 }
 
 
@@ -243,7 +211,8 @@ void bx_nogui_gui_c::dimension_update(unsigned x, unsigned y, unsigned fheight,
 // xdim: x dimension of bitmap
 // ydim: y dimension of bitmap
 
-unsigned bx_nogui_gui_c::create_bitmap(const unsigned char *bmap, unsigned xdim, unsigned ydim)
+  unsigned
+bx_gui_c::create_bitmap(const unsigned char *bmap, unsigned xdim, unsigned ydim)
 {
   UNUSED(bmap);
   UNUSED(xdim);
@@ -266,7 +235,8 @@ unsigned bx_nogui_gui_c::create_bitmap(const unsigned char *bmap, unsigned xdim,
 // f: a 'C' function pointer to callback when the mouse is clicked in
 //     the boundaries of this bitmap.
 
-unsigned bx_nogui_gui_c::headerbar_bitmap(unsigned bmap_id, unsigned alignment, void (*f)(void))
+  unsigned
+bx_gui_c::headerbar_bitmap(unsigned bmap_id, unsigned alignment, void (*f)(void))
 {
   UNUSED(bmap_id);
   UNUSED(alignment);
@@ -280,7 +250,8 @@ unsigned bx_nogui_gui_c::headerbar_bitmap(unsigned bmap_id, unsigned alignment,
 // Show (redraw) the current headerbar, which is composed of
 // currently installed bitmaps.
 
-void bx_nogui_gui_c::show_headerbar(void)
+  void
+bx_gui_c::show_headerbar(void)
 {
 }
 
@@ -298,7 +269,8 @@ void bx_nogui_gui_c::show_headerbar(void)
 // hbar_id: headerbar slot ID
 // bmap_id: bitmap ID
 
-void bx_nogui_gui_c::replace_bitmap(unsigned hbar_id, unsigned bmap_id)
+  void
+bx_gui_c::replace_bitmap(unsigned hbar_id, unsigned bmap_id)
 {
   UNUSED(hbar_id);
   UNUSED(bmap_id);
@@ -310,18 +282,8 @@ void bx_nogui_gui_c::replace_bitmap(unsigned hbar_id, unsigned bmap_id)
 // Called before bochs terminates, to allow for a graceful
 // exit from the native GUI mechanism.
 
-void bx_nogui_gui_c::exit(void)
+  void
+bx_gui_c::exit(void)
 {
-  BX_INFO(("bx_nogui_gui_c::exit() not implemented yet."));
+  fprintf(stderr, "# WARNING: win32: bx_gui_c::exit() not implemented yet.\n");
 }
-
-
-// ::MOUSE_ENABLED_CHANGED_SPECIFIC()
-//
-// Called whenever the mouse capture mode should be changed.
-
-void bx_nogui_gui_c::mouse_enabled_changed_specific(bx_bool val)
-{
-}
-
-#endif /* if BX_WITH_NOGUI */
