@@ -1,8 +1,10 @@
-/////////////////////////////////////////////////////////////////////////
-// $Id: pic.h 11148 2012-04-23 17:06:19Z vruppert $
-/////////////////////////////////////////////////////////////////////////
+//  Copyright (C) 2000  MandrakeSoft S.A.
 //
-//  Copyright (C) 2002-2009  The Bochs Project
+//    MandrakeSoft S.A.
+//    43, rue d'Aboukir
+//    75002 Paris - France
+//    http://www.linux-mandrake.com/
+//    http://www.mandrakesoft.com/
 //
 //  This library is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU Lesser General Public
@@ -16,19 +18,19 @@
 //
 //  You should have received a copy of the GNU Lesser General Public
 //  License along with this library; if not, write to the Free Software
-//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 
-#ifndef BX_IODEV_PIC_H
-#define BX_IODEV_PIC_H
 
 #if BX_USE_PIC_SMF
 #  define BX_PIC_SMF  static
-#  define BX_PIC_THIS thePic->
+#  define BX_PIC_THIS bx_pic.
 #else
 #  define BX_PIC_SMF
 #  define BX_PIC_THIS this->
 #endif
 
+
+
 typedef struct {
   Bit8u single_PIC;        /* 0=cascaded PIC, 1=master only */
   Bit8u interrupt_offset;  /* programmable interrupt vector offset */
@@ -36,7 +38,7 @@ typedef struct {
     Bit8u   slave_connect_mask; /* for master, a bit for each interrupt line
                                    0=not connect to a slave, 1=connected */
     Bit8u   slave_id;           /* for slave, id number of slave PIC */
-  } u;
+    } u;
   Bit8u sfnm;              /* specially fully nested mode: 0=no, 1=yes*/
   Bit8u buffered_mode;     /* 0=no buffered mode, 1=buffered mode */
   Bit8u master_slave;      /* master/slave: 0=slave PIC, 1=master PIC */
@@ -46,41 +48,33 @@ typedef struct {
   Bit8u irr;               /* interrupt request register */
   Bit8u read_reg_select;   /* 0=IRR, 1=ISR */
   Bit8u irq;               /* current IRQ number */
-  Bit8u lowest_priority;   /* current lowest priority irq */
-  bx_bool INT;             /* INT request pin of PIC */
-  Bit8u IRQ_in;            /* IRQ pins of PIC */
+  Boolean INT;             /* INT request pin of PIC */
   struct {
-    bx_bool in_init;
-    bx_bool requires_4;
-    Bit8u   byte_expected;
-  } init;
-  bx_bool special_mask;
-  bx_bool polled;            /* Set when poll command is issued. */
-  bx_bool rotate_on_autoeoi; /* Set when should rotate in auto-eoi mode. */
-  Bit8u edge_level; /* bitmap for irq mode (0=edge, 1=level) */
-} bx_pic_t;
+    Boolean    in_init;
+    Boolean    requires_4;
+    int        byte_expected;
+    } init;
+  Boolean special_mask;
+  } bx_pic_t;
 
 
-class bx_pic_c : public bx_pic_stub_c {
+class bx_pic_c {
+
 public:
-  bx_pic_c();
-  virtual ~bx_pic_c();
-  virtual void init(void);
-  virtual void reset(unsigned type);
-  virtual void lower_irq(unsigned irq_no);
-  virtual void raise_irq(unsigned irq_no);
-  virtual void set_mode(bx_bool ma_sl, Bit8u mode);
-  virtual Bit8u IAC(void);
-#if BX_DEBUGGER
-  virtual void debug_dump(int argc, char **argv);
-#endif
-  virtual void register_state(void);
+  bx_pic_c(void);
+  ~bx_pic_c(void);
+  BX_PIC_SMF void   init(bx_devices_c *);
+  BX_PIC_SMF void   trigger_irq(unsigned irq_no);
+  BX_PIC_SMF void   untrigger_irq(unsigned irq_no);
+  BX_PIC_SMF Bit8u  IAC(void);
 
 private:
   struct {
     bx_pic_t master_pic;
     bx_pic_t slave_pic;
-  } s;
+    } s;
+
+  bx_devices_c *devices;
 
   static Bit32u read_handler(void *this_ptr, Bit32u address, unsigned io_len);
   static void   write_handler(void *this_ptr, Bit32u address, Bit32u value, unsigned io_len);
@@ -91,7 +85,9 @@ private:
 
   BX_PIC_SMF void   service_master_pic(void);
   BX_PIC_SMF void   service_slave_pic(void);
-  BX_PIC_SMF void   clear_highest_interrupt(bx_pic_t *pic);
-};
+  BX_PIC_SMF void   show_pic_state(void);
+  };
 
+#if BX_USE_PIC_SMF
+extern bx_pic_c bx_pic;
 #endif
