@@ -1,8 +1,10 @@
-/////////////////////////////////////////////////////////////////////////
-// $Id: load32bitOShack.cc 12590 2015-01-03 13:53:52Z sshwarts $
-/////////////////////////////////////////////////////////////////////////
+//  Copyright (C) 2000  MandrakeSoft S.A.
 //
-//  Copyright (C) 2001-2014  The Bochs Project
+//    MandrakeSoft S.A.
+//    43, rue d'Aboukir
+//    75002 Paris - France
+//    http://www.linux-mandrake.com/
+//    http://www.mandrakesoft.com/
 //
 //  This library is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU Lesser General Public
@@ -16,60 +18,60 @@
 //
 //  You should have received a copy of the GNU Lesser General Public
 //  License along with this library; if not, write to the Free Software
-//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+
+
+
 
 #include "bochs.h"
-#include "param_names.h"
-#include "cpu/cpu.h"
-#include "iodev/iodev.h"
-#define LOG_THIS genlog->
+
+
 
 static void bx_load_linux_hack(void);
 static void bx_load_null_kernel_hack(void);
 static Bit32u bx_load_kernel_image(char *path, Bit32u paddr);
 
-void bx_load32bitOSimagehack(void)
+  void
+bx_load32bitOSimagehack(void)
 {
-  if (SIM->get_param_string(BXPN_LOAD32BITOS_IOLOG) &&
-     (SIM->get_param_string(BXPN_LOAD32BITOS_IOLOG)->getptr()[0] != '\0'))
-  {
+  // Replay IO from log to initialize IO devices to
+  // a reasonable state needed for the OS.  This is done
+  // in lieu of running the 16-bit BIOS to init things,
+  // since we want to test straight 32bit stuff for
+  // freemware.
 
-    // Replay IO from log to initialize IO devices to
-    // a reasonable state needed for the OS.  This is done
-    // in lieu of running the 16-bit BIOS to init things,
-    // since we want to test straight 32bit stuff for
-    // freemware.
+  FILE *fp;
 
-    FILE *fp = fopen(SIM->get_param_string(BXPN_LOAD32BITOS_IOLOG)->getptr(), "r");
-    if (fp == NULL) {
-      BX_PANIC(("could not open IO init file."));
+  fp = fopen(bx_options.load32bitOSImage.iolog, "r");
+
+  if (fp == NULL) {
+    bx_panic("could not open IO init file.\n");
     }
 
-    while (1) {
-      unsigned len, op, port, val;
-      int ret;
-      ret = fscanf(fp, "%u %u %x %x\n", &len, &op, &port, &val);
-      if (ret != 4) {
-        BX_PANIC(("could not open IO init file."));
+  while (1) {
+    unsigned len, op, port, val;
+    int ret;
+    ret = fscanf(fp, "%u %u %x %x\n",
+      &len, &op, &port, &val);
+    if (ret != 4) {
+      bx_panic("could not open IO init file.\n");
       }
-      if (op == 0) {
-        // read
-        bx_devices.inp(port, len);
+    if (op == 0) {
+      // read
+      (void) bx_devices.inp(port, len);
       }
-      else if (op == 1) {
-        // write
-        bx_devices.outp(port, val, len);
+    else if (op == 1) {
+      // write
+      bx_devices.outp(port, val, len);
       }
-      else {
-        BX_PANIC(("bad IO op in init filen"));
+    else {
+      bx_panic("bad IO op in init filen");
       }
-      if (feof(fp)) break;
+    if (feof(fp)) break;
     }
-    fclose(fp);
-  } //if iolog file to load
 
   // Invoke proper hack depending on which OS image we're loading
-  switch (SIM->get_param_enum(BXPN_LOAD32BITOS_WHICH)->get()) {
+  switch (bx_options.load32bitOSImage.whichOS) {
     case Load32bitOSLinux:
       bx_load_linux_hack();
       break;
@@ -77,7 +79,7 @@ void bx_load32bitOSimagehack(void)
       bx_load_null_kernel_hack();
       break;
     default:
-      BX_PANIC(("load32bitOSImage: OS not recognized"));
+      bx_panic("load32bitOSImage: OS not recognized\n");
     }
 }
 
@@ -86,7 +88,6 @@ struct gdt_entry
   Bit32u low;
   Bit32u high;
 };
-
 struct linux_setup_params
 {
    /* 0x000 */ Bit8u   orig_x;
@@ -126,12 +127,13 @@ struct linux_setup_params
    /* 0x800 */ Bit8u   commandline[2048];
 };
 
-static void bx_load_linux_setup_params(Bit32u initrd_start, Bit32u initrd_size)
+  static void
+bx_load_linux_setup_params( Bit32u initrd_start, Bit32u initrd_size )
 {
   struct linux_setup_params *params =
-         (struct linux_setup_params *) BX_MEM(0)->get_vector(0x00090000);
+         (struct linux_setup_params *) &BX_MEM_THIS vector[0x00090000];
 
-  memset(params, '\0', sizeof(*params));
+  memset( params, '\0', sizeof(*params) );
 
   /* Video settings (standard VGA) */
   params->orig_x = 0;
@@ -145,7 +147,7 @@ static void bx_load_linux_setup_params(Bit32u initrd_start, Bit32u initrd_size)
   params->orig_video_ega_bx = 3;
 
   /* Memory size (total mem - 1MB, in KB) */
-  params->memory_size_ext = (Bit32u)(BX_MEM(0)->get_memory_len()/(1024*1024) - 1) * 1024;
+  params->memory_size_ext = (BX_MEM_THIS megabytes - 1) * 1024;
 
   /* Boot parameters */
   params->loader_type = 1;
@@ -162,7 +164,8 @@ static void bx_load_linux_setup_params(Bit32u initrd_start, Bit32u initrd_size)
   params->gdt[3].low  = 0x0000ffff;
 }
 
-void bx_load_linux_hack(void)
+  void
+bx_load_linux_hack(void)
 {
   Bit32u initrd_start = 0, initrd_size = 0;
 
@@ -170,82 +173,81 @@ void bx_load_linux_hack(void)
   // Set CPU and memory features which are assumed at this point.
 
   // Load Linux kernel image
-  bx_load_kernel_image(SIM->get_param_string(BXPN_LOAD32BITOS_PATH)->getptr(), 0x100000);
+  bx_load_kernel_image( bx_options.load32bitOSImage.path, 0x100000 );
 
   // Load initial ramdisk image if requested
-  char *tmpPtr = SIM->get_param_string(BXPN_LOAD32BITOS_INITRD)->getptr();
-  if (tmpPtr && tmpPtr[0]) /* The initial value is "" and not NULL */
+  if ( bx_options.load32bitOSImage.initrd )
   {
     initrd_start = 0x00800000;  /* FIXME: load at top of memory */
-    initrd_size  = bx_load_kernel_image(tmpPtr, initrd_start);
+    initrd_size  = bx_load_kernel_image( bx_options.load32bitOSImage.initrd, initrd_start );
   }
 
   // Setup Linux startup parameters buffer
-  bx_load_linux_setup_params(initrd_start, initrd_size);
+  bx_load_linux_setup_params( initrd_start, initrd_size );
 
   // Enable A20 line
-  BX_SET_ENABLE_A20(1);
+  BX_SET_ENABLE_A20( 1 );
 
   // Setup PICs the way Linux likes it
-  BX_OUTP(0x20, 0x11, 1);
-  BX_OUTP(0xA0, 0x11, 1);
-  BX_OUTP(0x21, 0x20, 1);
-  BX_OUTP(0xA1, 0x28, 1);
-  BX_OUTP(0x21, 0x04, 1);
-  BX_OUTP(0xA1, 0x02, 1);
-  BX_OUTP(0x21, 0x01, 1);
-  BX_OUTP(0xA1, 0x01, 1);
-  BX_OUTP(0x21, 0xFF, 1);
-  BX_OUTP(0xA1, 0xFB, 1);
+  BX_OUTP( 0x20, 0x11, 1 );
+  BX_OUTP( 0xA0, 0x11, 1 );
+  BX_OUTP( 0x21, 0x20, 1 );
+  BX_OUTP( 0xA1, 0x28, 1 );
+  BX_OUTP( 0x21, 0x04, 1 );
+  BX_OUTP( 0xA1, 0x02, 1 );
+  BX_OUTP( 0x21, 0x01, 1 );
+  BX_OUTP( 0xA1, 0x01, 1 );
+  BX_OUTP( 0x21, 0xFF, 1 );
+  BX_OUTP( 0xA1, 0xFB, 1 );
 
   // Disable interrupts and NMIs
-  BX_CPU(0)->clear_IF();
-  BX_OUTP(0x70, 0x80, 1);
+  BX_CPU_THIS_PTR eflags.if_ = 0;
+  BX_OUTP( 0x70, 0x80, 1 );
 
   // Enter protected mode
-  // Fixed by george (kyriazis at nvidia.com)
-  BX_CPU(0)->cr0.set_PE(1); // protected mode
-
-  // load esi with real_mode
-  BX_CPU(0)->gen_reg[BX_32BIT_REG_ESI].dword.erx = 0x90000;
+  BX_CPU_THIS_PTR cr0.pe = 1;
+  BX_CPU_THIS_PTR cr0.val32 |= 0x01;
 
   // Set up initial GDT
-  BX_CPU(0)->gdtr.limit = 0x400;
-  BX_CPU(0)->gdtr.base  = 0x00090400;
+  BX_CPU_THIS_PTR gdtr.limit = 0x400;
+  BX_CPU_THIS_PTR gdtr.base  = 0x00090400;
 
   // Jump to protected mode entry point
-  BX_CPU(0)->jump_protected(NULL, 0x10, 0x100000);
+  BX_CPU_THIS_PTR jump_protected( NULL, 0x10, 0x00100000 );
 }
 
-void bx_load_null_kernel_hack(void)
+  void
+bx_load_null_kernel_hack(void)
 {
   // The RESET function will have been called first.
   // Set CPU and memory features which are assumed at this point.
 
-  bx_load_kernel_image(SIM->get_param_string(BXPN_LOAD32BITOS_PATH)->getptr(), 0x100000);
+  bx_load_kernel_image(bx_options.load32bitOSImage.path, 0x100000);
 
   // EIP deltas
-  BX_CPU(0)->prev_rip = BX_CPU(0)->gen_reg[BX_32BIT_REG_EIP].dword.erx = 0x100000;
+  BX_CPU_THIS_PTR prev_eip =
+  BX_CPU_THIS_PTR eip = 0x00100000;
 
   // CS deltas
-  BX_CPU(0)->sregs[BX_SEG_REG_CS].cache.u.segment.base = 0x00000000;
-  BX_CPU(0)->sregs[BX_SEG_REG_CS].cache.u.segment.limit_scaled = 0xFFFFFFFF;
-  BX_CPU(0)->sregs[BX_SEG_REG_CS].cache.u.segment.g   = 1; // page granularity
-  BX_CPU(0)->sregs[BX_SEG_REG_CS].cache.u.segment.d_b = 1; // 32bit
+  BX_CPU_THIS_PTR sregs[BX_SEG_REG_CS].cache.u.segment.base = 0x00000000;
+  BX_CPU_THIS_PTR sregs[BX_SEG_REG_CS].cache.u.segment.limit = 0xFFFFF;
+  BX_CPU_THIS_PTR sregs[BX_SEG_REG_CS].cache.u.segment.limit_scaled = 0xFFFFFFFF;
+  BX_CPU_THIS_PTR sregs[BX_SEG_REG_CS].cache.u.segment.g   = 1; // page gran
+  BX_CPU_THIS_PTR sregs[BX_SEG_REG_CS].cache.u.segment.d_b = 1; // 32bit
 
   // DS deltas
-  BX_CPU(0)->sregs[BX_SEG_REG_DS].cache.u.segment.base = 0x00000000;
-  BX_CPU(0)->sregs[BX_SEG_REG_DS].cache.u.segment.limit_scaled = 0xFFFFFFFF;
-  BX_CPU(0)->sregs[BX_SEG_REG_DS].cache.u.segment.g   = 1; // page granularity
-  BX_CPU(0)->sregs[BX_SEG_REG_DS].cache.u.segment.d_b = 1; // 32bit
+  BX_CPU_THIS_PTR sregs[BX_SEG_REG_DS].cache.u.segment.base = 0x00000000;
+  BX_CPU_THIS_PTR sregs[BX_SEG_REG_DS].cache.u.segment.limit = 0xFFFFF;
+  BX_CPU_THIS_PTR sregs[BX_SEG_REG_DS].cache.u.segment.limit_scaled = 0xFFFFFFFF;
+  BX_CPU_THIS_PTR sregs[BX_SEG_REG_DS].cache.u.segment.g   = 1; // page gran
+  BX_CPU_THIS_PTR sregs[BX_SEG_REG_DS].cache.u.segment.d_b = 1; // 32bit
 
   // CR0 deltas
-  BX_CPU(0)->cr0.set_PE(1); // protected mode
-
-  BX_CPU(0)->handleCpuModeChange();
+  BX_CPU_THIS_PTR cr0.pe = 1; // protected mode
 }
 
-Bit32u bx_load_kernel_image(char *path, Bit32u paddr)
+  Bit32u
+bx_load_kernel_image(char *path, Bit32u paddr)
 {
   struct stat stat_buf;
   int fd, ret;
@@ -259,36 +261,38 @@ Bit32u bx_load_kernel_image(char *path, Bit32u paddr)
 #endif
            );
   if (fd < 0) {
-    BX_INFO(("load_kernel_image: couldn't open image file '%s'.", path));
-    BX_EXIT(1);
-  }
+    fprintf(stderr, "load_kernel_image: couldn't open image file '%s'.\n", path);
+    exit(1);
+    }
   ret = fstat(fd, &stat_buf);
   if (ret) {
-    BX_INFO(("load_kernel_image: couldn't stat image file '%s'.", path));
-    BX_EXIT(1);
-  }
+    fprintf(stderr, "load_kernel_image: couldn't stat image file '%s'.\n", path);
+    exit(1);
+    }
 
-  size = (unsigned long) stat_buf.st_size;
+  size = stat_buf.st_size;
   page_size = ((Bit32u)size + 0xfff) & ~0xfff;
 
-  if ((paddr + size) > BX_MEM(0)->get_memory_len()) {
-    BX_INFO(("load_kernel_image: address range > physical memsize!"));
-    BX_EXIT(1);
-  }
+  if ( (paddr + size) > BX_MEM_THIS len ) {
+    fprintf(stderr, "load_kernel_image: address range > physical memsize!\n");
+    exit(1);
+    }
 
   offset = 0;
   while (size > 0) {
-    ret = read(fd, (bx_ptr_t) BX_MEM(0)->get_vector(paddr + offset), size);
+    ret = read(fd, (bx_ptr_t) &BX_MEM_THIS vector[paddr + offset], size);
     if (ret <= 0) {
-      BX_INFO(("load_kernel_image: read failed on image"));
-      BX_EXIT(1);
-    }
+      fprintf(stderr, "load_kernel_image: read failed on image\n");
+      exit(1);
+      }
     size -= ret;
     offset += ret;
-  }
+    }
   close(fd);
-  BX_INFO(("load_kernel_image: '%s', size=%u read into memory at %08x",
-       path, (unsigned) stat_buf.st_size, (unsigned) paddr));
+  fprintf(stderr, "#(%u) load_kernel_image: '%s', size=%u read into memory at %08x\n",
+          BX_SIM_ID, path,
+          (unsigned) stat_buf.st_size,
+          (unsigned) paddr);
 
   return page_size;
 }
