@@ -1,8 +1,10 @@
-/////////////////////////////////////////////////////////////////////////
-// $Id: make_cmos_image.cc 12594 2015-01-07 16:17:40Z sshwarts $
-/////////////////////////////////////////////////////////////////////////
+//  Copyright (C) 2000  MandrakeSoft S.A.
 //
-//  Copyright (C) 2001-2014  The Bochs Project
+//    MandrakeSoft S.A.
+//    43, rue d'Aboukir
+//    75002 Paris - France
+//    http://www.linux-mandrake.com/
+//    http://www.mandrakesoft.com/
 //
 //  This library is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU Lesser General Public
@@ -16,7 +18,7 @@
 //
 //  You should have received a copy of the GNU Lesser General Public
 //  License along with this library; if not, write to the Free Software
-//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 
 
 // Program which generates sample CMOS image files
@@ -29,7 +31,6 @@ extern "C" {
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <unistd.h>
-#include <stdlib.h>
 }
 
 
@@ -43,7 +44,7 @@ unsigned char cmos[] = {
   0x00, 0x48, 0x2b, 0x03, 0x03, 0x03, 0x04, 0xce,
   0x00, 0x3c, 0x19, 0xff, 0xff, 0xf0, 0x00, 0xf0,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x7b
-};
+  };
 
 #else
 unsigned char cmos[] = {
@@ -64,7 +65,7 @@ unsigned char cmos[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,  // 70
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
-};
+  };
 #endif
 
   int
@@ -75,26 +76,23 @@ main(int argc, char *argv[])
   if (argc != 2) {
     fprintf(stderr, "usage: %s pathname\n", argv[0]);
     exit(1);
-  }
+    }
 
   fd = open(argv[1], O_WRONLY | O_CREAT
 #ifdef O_BINARY
-                              | O_BINARY
+                                    | O_BINARY
 #endif
-           , S_IRUSR | S_IWUSR);
+           , S_IRUSR | S_IWUSR
+           );
   if (fd < 0) {
     perror("trying to open cmos image file to write.\n");
     exit(1);
-  }
+    }
 
   ret = write(fd, cmos, sizeof(cmos));
   if (ret != sizeof(cmos)) {
     perror("write() did not write all CMOS data.\n");
-    close(fd);
     exit(1);
-  }
-
-  close(fd);
+    }
   printf("CMOS data successfuly written to file '%s'.\n", argv[1]);
-  return 0;
 }
