@@ -1,8 +1,4 @@
-/////////////////////////////////////////////////////////////////////////
-// $Id: sb16ctrl.c,v 1.7 2009-02-08 09:05:52 vruppert Exp $
-/////////////////////////////////////////////////////////////////////////
-//
-//  Copyright (C) 2001  MandrakeSoft S.A.
+//  Copyright (C) 2000  MandrakeSoft S.A.
 //
 //    MandrakeSoft S.A.
 //    43, rue d'Aboukir
@@ -22,15 +18,15 @@
 //
 //  You should have received a copy of the GNU Lesser General Public
 //  License along with this library; if not, write to the Free Software
-//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 
 // This file (SB16CTRL.C) written and donated by Josef Drexler
 
 
 
 
-// The purpose of this program is to provide runtime configuration
-// options to the SB16 Emulator until Bochs has a more sophisticated
+// The purpose of this program is to provide runtime configuration 
+// options to the SB16 Emulator until Bochs has a more sophisticated 
 // user interface allowing to do these things better.
 
 
@@ -43,7 +39,7 @@
 #	include <dos.h>
 #endif
 
-#if defined(__linux__) || defined(__GNU__) || defined(__GLIBC__)
+#ifdef linux
 #	include <sys/io.h>
 #	include <errno.h>
 #	define inp inb
@@ -80,7 +76,7 @@ void writeemul(int value)
 /* Enable access to the emulator port */
 void enableport()
 {
-#if defined(__linux__) || defined(__GNU__) || defined(__GLIBC__)
+#ifdef linux
   if (ioperm(EMULPORT, 1, 1)) {
     printf("Could not access emulator port %03x: %s.\n", EMULPORT, strerror(errno));
     exit(1);
@@ -281,7 +277,7 @@ void loadmap(char *map)
   for (i=0;i<6;i++) {
     if (nextnum) {
       trans[i] = strtoi(nextnum, &nextnum, 0);
-      if ( (!nextnum) ||
+      if ( (!nextnum) || 
 	   ( (trans[i] > 127) && (trans[i] < 255) ) ||
 	   (trans[i] > 255) )
 	printf("Parse error in value %d%s. Command ignored.", i, ofline);
